# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cometbft/services/block_results/v1/block_results.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.cometbft.abci.v1 import types_pb2 as cometbft_dot_abci_dot_v1_dot_types__pb2
from pyinjective.proto.cometbft.types.v1 import params_pb2 as cometbft_dot_types_dot_v1_dot_params__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n6cometbft/services/block_results/v1/block_results.proto\x12\"cometbft.services.block_results.v1\x1a\x1c\x63ometbft/abci/v1/types.proto\x1a\x1e\x63ometbft/types/v1/params.proto\"0\n\x16GetBlockResultsRequest\x12\x16\n\x06height\x18\x01 \x01(\x03R\x06height\"\x84\x03\n\x17GetBlockResultsResponse\x12\x16\n\x06height\x18\x01 \x01(\x03R\x06height\x12=\n\ntx_results\x18\x02 \x03(\x0b\x32\x1e.cometbft.abci.v1.ExecTxResultR\ttxResults\x12K\n\x15\x66inalize_block_events\x18\x03 \x03(\x0b\x32\x17.cometbft.abci.v1.EventR\x13\x66inalizeBlockEvents\x12N\n\x11validator_updates\x18\x04 \x03(\x0b\x32!.cometbft.abci.v1.ValidatorUpdateR\x10validatorUpdates\x12Z\n\x17\x63onsensus_param_updates\x18\x05 \x01(\x0b\x32\".cometbft.types.v1.ConsensusParamsR\x15\x63onsensusParamUpdates\x12\x19\n\x08\x61pp_hash\x18\x06 \x01(\x0cR\x07\x61ppHashB\xa7\x02\n&com.cometbft.services.block_results.v1B\x11\x42lockResultsProtoP\x01ZCgithub.com/cometbft/cometbft/api/cometbft/services/block_results/v1\xa2\x02\x03\x43SB\xaa\x02!Cometbft.Services.BlockResults.V1\xca\x02!Cometbft\\Services\\BlockResults\\V1\xe2\x02-Cometbft\\Services\\BlockResults\\V1\\GPBMetadata\xea\x02$Cometbft::Services::BlockResults::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cometbft.services.block_results.v1.block_results_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n&com.cometbft.services.block_results.v1B\021BlockResultsProtoP\001ZCgithub.com/cometbft/cometbft/api/cometbft/services/block_results/v1\242\002\003CSB\252\002!Cometbft.Services.BlockResults.V1\312\002!Cometbft\\Services\\BlockResults\\V1\342\002-Cometbft\\Services\\BlockResults\\V1\\GPBMetadata\352\002$Cometbft::Services::BlockResults::V1'
  _globals['_GETBLOCKRESULTSREQUEST']._serialized_start=156
  _globals['_GETBLOCKRESULTSREQUEST']._serialized_end=204
  _globals['_GETBLOCKRESULTSRESPONSE']._serialized_start=207
  _globals['_GETBLOCKRESULTSRESPONSE']._serialized_end=595
# @@protoc_insertion_point(module_scope)



from typing import Any, Callable, Dict

from grpc.aio import Channel

from pyinjective.core.network import CookieAssistant
from pyinjective.proto.cosmos.tx.v1beta1 import service_pb2 as tx_service, service_pb2_grpc as tx_service_grpc
from pyinjective.utils.grpc_api_request_assistant import GrpcApiRequestAssistant


class TxGrpcApi:
    def __init__(self, channel: Channel, cookie_assistant: CookieAssistant):
        self._stub = tx_service_grpc.ServiceStub(channel)
        self._assistant = GrpcApiRequestAssistant(cookie_assistant=cookie_assistant)

    async def simulate(self, tx_bytes: bytes) -> Dict[str, Any]:
        request = tx_service.SimulateRequest(tx_bytes=tx_bytes)
        response = await self._execute_call(call=self._stub.Simulate, request=request)

        return response

    async def fetch_tx(self, hash: str) -> Dict[str, Any]:
        request = tx_service.GetTxRequest(hash=hash)
        response = await self._execute_call(call=self._stub.GetTx, request=request)

        return response

    async def broadcast(self, tx_bytes: bytes, mode: int = tx_service.BROADCAST_MODE_ASYNC) -> Dict[str, Any]:
        request = tx_service.BroadcastTxRequest(tx_bytes=tx_bytes, mode=mode)
        response = await self._execute_call(call=self._stub.BroadcastTx, request=request)

        return response

    async def _execute_call(self, call: Callable, request) -> Dict[str, Any]:
        return await self._assistant.execute_call(call=call, request=request)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/wasmx/v1/authz.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.cosmwasm.wasm.v1 import authz_pb2 as cosmwasm_dot_wasm_dot_v1_dot_authz__pb2
from pyinjective.proto.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from pyinjective.proto.amino import amino_pb2 as amino_dot_amino__pb2
from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1einjective/wasmx/v1/authz.proto\x12\x12injective.wasmx.v1\x1a\x1c\x63osmwasm/wasm/v1/authz.proto\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x11\x61mino/amino.proto\x1a\x14gogoproto/gogo.proto\"\xc1\x01\n$ContractExecutionCompatAuthorization\x12\x42\n\x06grants\x18\x01 \x03(\x0b\x32\x1f.cosmwasm.wasm.v1.ContractGrantB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01R\x06grants:U\xca\xb4-\"cosmos.authz.v1beta1.Authorization\x8a\xe7\xb0**wasmx/ContractExecutionCompatAuthorizationB\xdb\x01\n\x16\x63om.injective.wasmx.v1B\nAuthzProtoP\x01ZKgithub.com/InjectiveLabs/injective-core/injective-chain/modules/wasmx/types\xa2\x02\x03IWX\xaa\x02\x12Injective.Wasmx.V1\xca\x02\x12Injective\\Wasmx\\V1\xe2\x02\x1eInjective\\Wasmx\\V1\\GPBMetadata\xea\x02\x14Injective::Wasmx::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'injective.wasmx.v1.authz_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\026com.injective.wasmx.v1B\nAuthzProtoP\001ZKgithub.com/InjectiveLabs/injective-core/injective-chain/modules/wasmx/types\242\002\003IWX\252\002\022Injective.Wasmx.V1\312\002\022Injective\\Wasmx\\V1\342\002\036Injective\\Wasmx\\V1\\GPBMetadata\352\002\024Injective::Wasmx::V1'
  _globals['_CONTRACTEXECUTIONCOMPATAUTHORIZATION'].fields_by_name['grants']._loaded_options = None
  _globals['_CONTRACTEXECUTIONCOMPATAUTHORIZATION'].fields_by_name['grants']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_CONTRACTEXECUTIONCOMPATAUTHORIZATION']._loaded_options = None
  _globals['_CONTRACTEXECUTIONCOMPATAUTHORIZATION']._serialized_options = b'\312\264-\"cosmos.authz.v1beta1.Authorization\212\347\260**wasmx/ContractExecutionCompatAuthorization'
  _globals['_CONTRACTEXECUTIONCOMPATAUTHORIZATION']._serialized_start=153
  _globals['_CONTRACTEXECUTIONCOMPATAUTHORIZATION']._serialized_end=346
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/msg/textual/v1/textual.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#cosmos/msg/textual/v1/textual.proto\x12\x15\x63osmos.msg.textual.v1\x1a google/protobuf/descriptor.proto:X\n\x16\x65xpert_custom_renderer\x12\x1f.google.protobuf.MessageOptions\x18\xf9\x8c\xa6\x05 \x01(\tR\x14\x65xpertCustomRendererB\xa0\x01\n\x19\x63om.cosmos.msg.textual.v1B\x0cTextualProtoP\x01\xa2\x02\x03\x43MT\xaa\x02\x15\x43osmos.Msg.Textual.V1\xca\x02\x15\x43osmos\\Msg\\Textual\\V1\xe2\x02!Cosmos\\Msg\\Textual\\V1\\GPBMetadata\xea\x02\x18\x43osmos::Msg::Textual::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.msg.textual.v1.textual_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\031com.cosmos.msg.textual.v1B\014TextualProtoP\001\242\002\003CMT\252\002\025Cosmos.Msg.Textual.V1\312\002\025Cosmos\\Msg\\Textual\\V1\342\002!Cosmos\\Msg\\Textual\\V1\\GPBMetadata\352\002\030Cosmos::Msg::Textual::V1'
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/erc20/v1beta1/genesis.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from pyinjective.proto.injective.erc20.v1beta1 import params_pb2 as injective_dot_erc20_dot_v1beta1_dot_params__pb2
from pyinjective.proto.injective.erc20.v1beta1 import erc20_pb2 as injective_dot_erc20_dot_v1beta1_dot_erc20__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%injective/erc20/v1beta1/genesis.proto\x12\x17injective.erc20.v1beta1\x1a\x14gogoproto/gogo.proto\x1a$injective/erc20/v1beta1/params.proto\x1a#injective/erc20/v1beta1/erc20.proto\"\x98\x01\n\x0cGenesisState\x12=\n\x06params\x18\x01 \x01(\x0b\x32\x1f.injective.erc20.v1beta1.ParamsB\x04\xc8\xde\x1f\x00R\x06params\x12I\n\x0btoken_pairs\x18\x02 \x03(\x0b\x32\".injective.erc20.v1beta1.TokenPairB\x04\xc8\xde\x1f\x00R\ntokenPairsB\xf6\x01\n\x1b\x63om.injective.erc20.v1beta1B\x0cGenesisProtoP\x01ZKgithub.com/InjectiveLabs/injective-core/injective-chain/modules/erc20/types\xa2\x02\x03IEX\xaa\x02\x17Injective.Erc20.V1beta1\xca\x02\x17Injective\\Erc20\\V1beta1\xe2\x02#Injective\\Erc20\\V1beta1\\GPBMetadata\xea\x02\x19Injective::Erc20::V1beta1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'injective.erc20.v1beta1.genesis_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\033com.injective.erc20.v1beta1B\014GenesisProtoP\001ZKgithub.com/InjectiveLabs/injective-core/injective-chain/modules/erc20/types\242\002\003IEX\252\002\027Injective.Erc20.V1beta1\312\002\027Injective\\Erc20\\V1beta1\342\002#Injective\\Erc20\\V1beta1\\GPBMetadata\352\002\031Injective::Erc20::V1beta1'
  _globals['_GENESISSTATE'].fields_by_name['params']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _globals['_GENESISSTATE'].fields_by_name['token_pairs']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['token_pairs']._serialized_options = b'\310\336\037\000'
  _globals['_GENESISSTATE']._serialized_start=164
  _globals['_GENESISSTATE']._serialized_end=316
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/base/v1beta1/coin.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from pyinjective.proto.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from pyinjective.proto.amino import amino_pb2 as amino_dot_amino__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1e\x63osmos/base/v1beta1/coin.proto\x12\x13\x63osmos.base.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x11\x61mino/amino.proto\"l\n\x04\x43oin\x12\x14\n\x05\x64\x65nom\x18\x01 \x01(\tR\x05\x64\x65nom\x12H\n\x06\x61mount\x18\x02 \x01(\tB0\xc8\xde\x1f\x00\xda\xde\x1f\x15\x63osmossdk.io/math.Int\xd2\xb4-\ncosmos.Int\xa8\xe7\xb0*\x01R\x06\x61mount:\x04\xe8\xa0\x1f\x01\"p\n\x07\x44\x65\x63\x43oin\x12\x14\n\x05\x64\x65nom\x18\x01 \x01(\tR\x05\x64\x65nom\x12I\n\x06\x61mount\x18\x02 \x01(\tB1\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDec\xd2\xb4-\ncosmos.DecR\x06\x61mount:\x04\xe8\xa0\x1f\x01\"I\n\x08IntProto\x12=\n\x03int\x18\x01 \x01(\tB+\xc8\xde\x1f\x00\xda\xde\x1f\x15\x63osmossdk.io/math.Int\xd2\xb4-\ncosmos.IntR\x03int\"O\n\x08\x44\x65\x63Proto\x12\x43\n\x03\x64\x65\x63\x18\x01 \x01(\tB1\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDec\xd2\xb4-\ncosmos.DecR\x03\x64\x65\x63\x42\xbe\x01\n\x17\x63om.cosmos.base.v1beta1B\tCoinProtoP\x01Z\"github.com/cosmos/cosmos-sdk/types\xa2\x02\x03\x43\x42X\xaa\x02\x13\x43osmos.Base.V1beta1\xca\x02\x13\x43osmos\\Base\\V1beta1\xe2\x02\x1f\x43osmos\\Base\\V1beta1\\GPBMetadata\xea\x02\x15\x43osmos::Base::V1beta1\xd8\xe1\x1e\x00\x80\xe2\x1e\x00\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.base.v1beta1.coin_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\027com.cosmos.base.v1beta1B\tCoinProtoP\001Z\"github.com/cosmos/cosmos-sdk/types\242\002\003CBX\252\002\023Cosmos.Base.V1beta1\312\002\023Cosmos\\Base\\V1beta1\342\002\037Cosmos\\Base\\V1beta1\\GPBMetadata\352\002\025Cosmos::Base::V1beta1\330\341\036\000\200\342\036\000'
  _globals['_COIN'].fields_by_name['amount']._loaded_options = None
  _globals['_COIN'].fields_by_name['amount']._serialized_options = b'\310\336\037\000\332\336\037\025cosmossdk.io/math.Int\322\264-\ncosmos.Int\250\347\260*\001'
  _globals['_COIN']._loaded_options = None
  _globals['_COIN']._serialized_options = b'\350\240\037\001'
  _globals['_DECCOIN'].fields_by_name['amount']._loaded_options = None
  _globals['_DECCOIN'].fields_by_name['amount']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec\322\264-\ncosmos.Dec'
  _globals['_DECCOIN']._loaded_options = None
  _globals['_DECCOIN']._serialized_options = b'\350\240\037\001'
  _globals['_INTPROTO'].fields_by_name['int']._loaded_options = None
  _globals['_INTPROTO'].fields_by_name['int']._serialized_options = b'\310\336\037\000\332\336\037\025cosmossdk.io/math.Int\322\264-\ncosmos.Int'
  _globals['_DECPROTO'].fields_by_name['dec']._loaded_options = None
  _globals['_DECPROTO'].fields_by_name['dec']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec\322\264-\ncosmos.Dec'
  _globals['_COIN']._serialized_start=123
  _globals['_COIN']._serialized_end=231
  _globals['_DECCOIN']._serialized_start=233
  _globals['_DECCOIN']._serialized_end=345
  _globals['_INTPROTO']._serialized_start=347
  _globals['_INTPROTO']._serialized_end=420
  _globals['_DECPROTO']._serialized_start=422
  _globals['_DECPROTO']._serialized_end=501
# @@protoc_insertion_point(module_scope)



from typing import Any, Callable, Dict, List, Optional

from grpc.aio import Channel

from pyinjective.client.model.pagination import PaginationOption
from pyinjective.core.network import CookieAssistant
from pyinjective.proto.injective.exchange.v1beta1 import (
    query_pb2 as exchange_query_pb,
    query_pb2_grpc as exchange_query_grpc,
)
from pyinjective.utils.grpc_api_request_assistant import GrpcApiRequestAssistant


class ChainGrpcExchangeApi:
    def __init__(self, channel: Channel, cookie_assistant: CookieAssistant):
        self._stub = exchange_query_grpc.QueryStub(channel)
        self._assistant = GrpcApiRequestAssistant(cookie_assistant=cookie_assistant)

    async def fetch_exchange_params(self) -> Dict[str, Any]:
        request = exchange_query_pb.QueryExchangeParamsRequest()
        response = await self._execute_call(call=self._stub.QueryExchangeParams, request=request)

        return response

    async def fetch_subaccount_deposits(
        self,
        subaccount_id: Optional[str] = None,
        subaccount_trader: Optional[str] = None,
        subaccount_nonce: Optional[int] = None,
    ) -> Dict[str, Any]:
        subaccount = None
        if subaccount_trader is not None or subaccount_nonce is not None:
            subaccount = exchange_query_pb.Subaccount(
                trader=subaccount_trader,
                subaccount_nonce=subaccount_nonce,
            )

        request = exchange_query_pb.QuerySubaccountDepositsRequest(subaccount_id=subaccount_id, subaccount=subaccount)
        response = await self._execute_call(call=self._stub.SubaccountDeposits, request=request)

        return response

    async def fetch_subaccount_deposit(
        self,
        subaccount_id: str,
        denom: str,
    ) -> Dict[str, Any]:
        request = exchange_query_pb.QuerySubaccountDepositRequest(
            subaccount_id=subaccount_id,
            denom=denom,
        )
        response = await self._execute_call(call=self._stub.SubaccountDeposit, request=request)

        return response

    async def fetch_exchange_balances(self) -> Dict[str, Any]:
        request = exchange_query_pb.QueryExchangeBalancesRequest()
        response = await self._execute_call(call=self._stub.ExchangeBalances, request=request)

        return response

    async def fetch_aggregate_volume(self, account: str) -> Dict[str, Any]:
        request = exchange_query_pb.QueryAggregateVolumeRequest(account=account)
        response = await self._execute_call(call=self._stub.AggregateVolume, request=request)

        return response

    async def fetch_aggregate_volumes(
        self,
        accounts: Optional[List[str]] = None,
        market_ids: Optional[List[str]] = None,
    ) -> Dict[str, Any]:
        request = exchange_query_pb.QueryAggregateVolumesRequest(accounts=accounts, market_ids=market_ids)
        response = await self._execute_call(call=self._stub.AggregateVolumes, request=request)

        return response

    async def fetch_aggregate_market_volume(self, market_id: str) -> Dict[str, Any]:
        request = exchange_query_pb.QueryAggregateMarketVolumeRequest(market_id=market_id)
        response = await self._execute_call(call=self._stub.AggregateMarketVolume, request=request)

        return response

    async def fetch_aggregate_market_volumes(self, market_ids: Optional[List[str]] = None) -> Dict[str, Any]:
        request = exchange_query_pb.QueryAggregateMarketVolumesRequest(market_ids=market_ids)
        response = await self._execute_call(call=self._stub.AggregateMarketVolumes, request=request)

        return response

    async def fetch_denom_decimal(self, denom: str) -> Dict[str, Any]:
        request = exchange_query_pb.QueryDenomDecimalRequest(denom=denom)
        response = await self._execute_call(call=self._stub.DenomDecimal, request=request)

        return response

    async def fetch_denom_decimals(self, denoms: Optional[List[str]] = None) -> Dict[str, Any]:
        request = exchange_query_pb.QueryDenomDecimalsRequest(denoms=denoms)
        response = await self._execute_call(call=self._stub.DenomDecimals, request=request)

        return response

    async def fetch_spot_markets(
        self,
        status: Optional[str] = None,
        market_ids: Optional[List[str]] = None,
    ) -> Dict[str, Any]:
        request = exchange_query_pb.QuerySpotMarketsRequest(
            status=status,
            market_ids=market_ids,
        )
        response = await self._execute_call(call=self._stub.SpotMarkets, request=request)

        return response

    async def fetch_spot_market(self, market_id: str) -> Dict[str, Any]:
        request = exchange_query_pb.QuerySpotMarketRequest(market_id=market_id)
        response = await self._execute_call(call=self._stub.SpotMarket, request=request)

        return response

    async def fetch_full_spot_markets(
        self,
        status: Optional[str] = None,
        market_ids: Optional[List[str]] = None,
        with_mid_price_and_tob: Optional[bool] = None,
    ) -> Dict[str, Any]:
        request = exchange_query_pb.QueryFullSpotMarketsRequest(
            status=status,
            market_ids=market_ids,
            with_mid_price_and_tob=with_mid_price_and_tob,
        )
        response = await self._execute_call(call=self._stub.FullSpotMarkets, request=request)

        return response

    async def fetch_full_spot_market(
        self,
        market_id: str,
        with_mid_price_and_tob: Optional[bool] = None,
    ) -> Dict[str, Any]:
        request = exchange_query_pb.QueryFullSpotMarketRequest(
            market_id=market_id,
            with_mid_price_and_tob=with_mid_price_and_tob,
        )
        response = await self._execute_call(call=self._stub.FullSpotMarket, request=request)

        return response

    async def fetch_spot_orderbook(
        self,
        market_id: str,
        order_side: Optional[str] = None,
        limit_cumulative_notional: Optional[str] = None,
        limit_cumulative_quantity: Optional[str] = None,
        pagination: Optional[PaginationOption] = None,
    ) -> Dict[str, Any]:
        limit = None
        if pagination is not None:
            limit = pagination.limit
        request = exchange_query_pb.QuerySpotOrderbookRequest(
            market_id=market_id,
            order_side=order_side,
            limit=limit,
            limit_cumulative_notional=limit_cumulative_notional,
            limit_cumulative_quantity=limit_cumulative_quantity,
        )
        response = await self._execute_call(call=self._stub.SpotOrderbook, request=request)

        return response

    async def fetch_trader_spot_orders(
        self,
        market_id: str,
        subaccount_id: str,
    ) -> Dict[str, Any]:
        request = exchange_query_pb.QueryTraderSpotOrdersRequest(
            market_id=market_id,
            subaccount_id=subaccount_id,
        )
        response = await self._execute_call(call=self._stub.TraderSpotOrders, request=request)

        return response

    async def fetch_account_address_spot_orders(
        self,
        market_id: str,
        account_address: str,
    ) -> Dict[str, Any]:
        request = exchange_query_pb.QueryAccountAddressSpotOrdersRequest(
            market_id=market_id,
            account_address=account_address,
        )
        response = await self._execute_call(call=self._stub.AccountAddressSpotOrders, request=request)

        return response

    async def fetch_spot_orders_by_hashes(
        self,
        market_id: str,
        subaccount_id: str,
        order_hashes: List[str],
    ) -> Dict[str, Any]:
        request = exchange_query_pb.QuerySpotOrdersByHashesRequest(
            market_id=market_id,
            subaccount_id=subaccount_id,
            order_hashes=order_hashes,
        )
        response = await self._execute_call(call=self._stub.SpotOrdersByHashes, request=request)

        return response

    async def fetch_subaccount_orders(
        self,
        subaccount_id: str,
        market_id: str,
    ) -> Dict[str, Any]:
        request = exchange_query_pb.QuerySubaccountOrdersRequest(
            subaccount_id=subaccount_id,
            market_id=market_id,
        )
        response = await self._execute_call(call=self._stub.SubaccountOrders, request=request)

        return response

    async def fetch_trader_spot_transient_orders(
        self,
        market_id: str,
        subaccount_id: str,
    ) -> Dict[str, Any]:
        request = exchange_query_pb.QueryTraderSpotOrdersRequest(
            market_id=market_id,
            subaccount_id=subaccount_id,
        )
        response = await self._execute_call(call=self._stub.TraderSpotTransientOrders, request=request)

        return response

    async def fetch_spot_mid_price_and_tob(
        self,
        market_id: str,
    ) -> Dict[str, Any]:
        request = exchange_query_pb.QuerySpotMidPriceAndTOBRequest(
            market_id=market_id,
        )
        response = await self._execute_call(call=self._stub.SpotMidPriceAndTOB, request=request)

        return response

    async def fetch_derivative_mid_price_and_tob(
        self,
        market_id: str,
    ) -> Dict[str, Any]:
        request = exchange_query_pb.QueryDerivativeMidPriceAndTOBRequest(
            market_id=market_id,
        )
        response = await self._execute_call(call=self._stub.DerivativeMidPriceAndTOB, request=request)

        return response

    async def fetch_derivative_orderbook(
        self,
        market_id: str,
        limit_cumulative_notional: Optional[str] = None,
        pagination: Optional[PaginationOption] = None,
    ) -> Dict[str, Any]:
        limit = None
        if pagination is not None:
            limit = pagination.limit
        request = exchange_query_pb.QueryDerivativeOrderbookRequest(
            market_id=market_id,
            limit=limit,
            limit_cumulative_notional=limit_cumulative_notional,
        )
        response = await self._execute_call(call=self._stub.DerivativeOrderbook, request=request)

        return response

    async def fetch_trader_derivative_orders(
        self,
        market_id: str,
        subaccount_id: str,
    ) -> Dict[str, Any]:
        request = exchange_query_pb.QueryTraderDerivativeOrdersRequest(
            market_id=market_id,
            subaccount_id=subaccount_id,
        )
        response = await self._execute_call(call=self._stub.TraderDerivativeOrders, request=request)

        return response

    async def fetch_account_address_derivative_orders(
        self,
        market_id: str,
        account_address: str,
    ) -> Dict[str, Any]:
        request = exchange_query_pb.QueryAccountAddressDerivativeOrdersRequest(
            market_id=market_id,
            account_address=account_address,
        )
        response = await self._execute_call(call=self._stub.AccountAddressDerivativeOrders, request=request)

        return response

    async def fetch_derivative_orders_by_hashes(
        self,
        market_id: str,
        subaccount_id: str,
        order_hashes: List[str],
    ) -> Dict[str, Any]:
        request = exchange_query_pb.QueryDerivativeOrdersByHashesRequest(
            market_id=market_id,
            subaccount_id=subaccount_id,
            order_hashes=order_hashes,
        )
        response = await self._execute_call(call=self._stub.DerivativeOrdersByHashes, request=request)

        return response

    async def fetch_trader_derivative_transient_orders(
        self,
        market_id: str,
        subaccount_id: str,
    ) -> Dict[str, Any]:
        request = exchange_query_pb.QueryTraderDerivativeOrdersRequest(
            market_id=market_id,
            subaccount_id=subaccount_id,
        )
        response = await self._execute_call(call=self._stub.TraderDerivativeTransientOrders, request=request)

        return response

    async def fetch_derivative_markets(
        self,
        status: Optional[str] = None,
        market_ids: Optional[List[str]] = None,
        with_mid_price_and_tob: Optional[bool] = None,
    ) -> Dict[str, Any]:
        request = exchange_query_pb.QueryDerivativeMarketsRequest(
            status=status,
            market_ids=market_ids,
            with_mid_price_and_tob=with_mid_price_and_tob,
        )
        response = await self._execute_call(call=self._stub.DerivativeMarkets, request=request)

        return response

    async def fetch_derivative_market(
        self,
        market_id: str,
    ) -> Dict[str, Any]:
        request = exchange_query_pb.QueryDerivativeMarketRequest(
            market_id=market_id,
        )
        response = await self._execute_call(call=self._stub.DerivativeMarket, request=request)

        return response

    async def fetch_derivative_market_address(
        self,
        market_id: str,
    ) -> Dict[str, Any]:
        request = exchange_query_pb.QueryDerivativeMarketAddressRequest(
            market_id=market_id,
        )
        response = await self._execute_call(call=self._stub.DerivativeMarketAddress, request=request)

        return response

    async def fetch_subaccount_trade_nonce(self, subaccount_id: str) -> Dict[str, Any]:
        request = exchange_query_pb.QuerySubaccountTradeNonceRequest(subaccount_id=subaccount_id)
        response = await self._execute_call(call=self._stub.SubaccountTradeNonce, request=request)

        return response

    async def fetch_positions(self) -> Dict[str, Any]:
        request = exchange_query_pb.QueryPositionsRequest()
        response = await self._execute_call(call=self._stub.Positions, request=request)

        return response

    async def fetch_subaccount_positions(self, subaccount_id: str) -> Dict[str, Any]:
        request = exchange_query_pb.QuerySubaccountPositionsRequest(subaccount_id=subaccount_id)
        response = await self._execute_call(call=self._stub.SubaccountPositions, request=request)

        return response

    async def fetch_subaccount_position_in_market(self, subaccount_id: str, market_id: str) -> Dict[str, Any]:
        request = exchange_query_pb.QuerySubaccountPositionInMarketRequest(
            subaccount_id=subaccount_id,
            market_id=market_id,
        )
        response = await self._execute_call(call=self._stub.SubaccountPositionInMarket, request=request)

        return response

    async def fetch_subaccount_effective_position_in_market(self, subaccount_id: str, market_id: str) -> Dict[str, Any]:
        request = exchange_query_pb.QuerySubaccountEffectivePositionInMarketRequest(
            subaccount_id=subaccount_id,
            market_id=market_id,
        )
        response = await self._execute_call(call=self._stub.SubaccountEffectivePositionInMarket, request=request)

        return response

    async def fetch_perpetual_market_info(self, market_id: str) -> Dict[str, Any]:
        request = exchange_query_pb.QueryPerpetualMarketInfoRequest(market_id=market_id)
        response = await self._execute_call(call=self._stub.PerpetualMarketInfo, request=request)

        return response

    async def fetch_expiry_futures_market_info(self, market_id: str) -> Dict[str, Any]:
        request = exchange_query_pb.QueryExpiryFuturesMarketInfoRequest(market_id=market_id)
        response = await self._execute_call(call=self._stub.ExpiryFuturesMarketInfo, request=request)

        return response

    async def fetch_perpetual_market_funding(self, market_id: str) -> Dict[str, Any]:
        request = exchange_query_pb.QueryPerpetualMarketFundingRequest(market_id=market_id)
        response = await self._execute_call(call=self._stub.PerpetualMarketFunding, request=request)

        return response

    async def fetch_subaccount_order_metadata(self, subaccount_id: str) -> Dict[str, Any]:
        request = exchange_query_pb.QuerySubaccountOrderMetadataRequest(subaccount_id=subaccount_id)
        response = await self._execute_call(call=self._stub.SubaccountOrderMetadata, request=request)

        return response

    async def fetch_trade_reward_points(
        self,
        accounts: Optional[List[str]] = None,
        pending_pool_timestamp: Optional[int] = None,
    ) -> Dict[str, Any]:
        request = exchange_query_pb.QueryTradeRewardPointsRequest(
            accounts=accounts,
            pending_pool_timestamp=pending_pool_timestamp,
        )
        response = await self._execute_call(call=self._stub.TradeRewardPoints, request=request)

        return response

    async def fetch_pending_trade_reward_points(
        self,
        accounts: Optional[List[str]] = None,
        pending_pool_timestamp: Optional[int] = None,
    ) -> Dict[str, Any]:
        request = exchange_query_pb.QueryTradeRewardPointsRequest(
            accounts=accounts,
            pending_pool_timestamp=pending_pool_timestamp,
        )
        response = await self._execute_call(call=self._stub.PendingTradeRewardPoints, request=request)

        return response

    async def fetch_trade_reward_campaign(self) -> Dict[str, Any]:
        request = exchange_query_pb.QueryTradeRewardCampaignRequest()
        response = await self._execute_call(call=self._stub.TradeRewardCampaign, request=request)

        return response

    async def fetch_fee_discount_account_info(
        self,
        account: str,
    ) -> Dict[str, Any]:
        request = exchange_query_pb.QueryFeeDiscountAccountInfoRequest(account=account)
        response = await self._execute_call(call=self._stub.FeeDiscountAccountInfo, request=request)

        return response

    async def fetch_fee_discount_schedule(self) -> Dict[str, Any]:
        request = exchange_query_pb.QueryFeeDiscountScheduleRequest()
        response = await self._execute_call(call=self._stub.FeeDiscountSchedule, request=request)

        return response

    async def fetch_balance_mismatches(self, dust_factor: int) -> Dict[str, Any]:
        request = exchange_query_pb.QueryBalanceMismatchesRequest(dust_factor=dust_factor)
        response = await self._execute_call(call=self._stub.BalanceMismatches, request=request)

        return response

    async def fetch_balance_with_balance_holds(self) -> Dict[str, Any]:
        request = exchange_query_pb.QueryBalanceWithBalanceHoldsRequest()
        response = await self._execute_call(call=self._stub.BalanceWithBalanceHolds, request=request)

        return response

    async def fetch_fee_discount_tier_statistics(self) -> Dict[str, Any]:
        request = exchange_query_pb.QueryFeeDiscountTierStatisticsRequest()
        response = await self._execute_call(call=self._stub.FeeDiscountTierStatistics, request=request)

        return response

    async def fetch_mito_vault_infos(self) -> Dict[str, Any]:
        request = exchange_query_pb.MitoVaultInfosRequest()
        response = await self._execute_call(call=self._stub.MitoVaultInfos, request=request)

        return response

    async def fetch_market_id_from_vault(self, vault_address: str) -> Dict[str, Any]:
        request = exchange_query_pb.QueryMarketIDFromVaultRequest(vault_address=vault_address)
        response = await self._execute_call(call=self._stub.QueryMarketIDFromVault, request=request)

        return response

    async def fetch_historical_trade_records(self, market_id: str) -> Dict[str, Any]:
        request = exchange_query_pb.QueryHistoricalTradeRecordsRequest(market_id=market_id)
        response = await self._execute_call(call=self._stub.HistoricalTradeRecords, request=request)

        return response

    async def fetch_is_opted_out_of_rewards(self, account: str) -> Dict[str, Any]:
        request = exchange_query_pb.QueryIsOptedOutOfRewardsRequest(account=account)
        response = await self._execute_call(call=self._stub.IsOptedOutOfRewards, request=request)

        return response

    async def fetch_opted_out_of_rewards_accounts(self) -> Dict[str, Any]:
        request = exchange_query_pb.QueryOptedOutOfRewardsAccountsRequest()
        response = await self._execute_call(call=self._stub.OptedOutOfRewardsAccounts, request=request)

        return response

    async def fetch_market_volatility(
        self,
        market_id: str,
        trade_grouping_sec: Optional[int] = None,
        max_age: Optional[int] = None,
        include_raw_history: Optional[bool] = None,
        include_metadata: Optional[bool] = None,
    ) -> Dict[str, Any]:
        trade_history_options = exchange_query_pb.TradeHistoryOptions()
        if trade_grouping_sec is not None:
            trade_history_options.trade_grouping_sec = trade_grouping_sec
        if max_age is not None:
            trade_history_options.max_age = max_age
        if include_raw_history is not None:
            trade_history_options.include_raw_history = include_raw_history
        if include_metadata is not None:
            trade_history_options.include_metadata = include_metadata
        request = exchange_query_pb.QueryMarketVolatilityRequest(
            market_id=market_id, trade_history_options=trade_history_options
        )
        response = await self._execute_call(call=self._stub.MarketVolatility, request=request)

        return response

    async def fetch_binary_options_markets(self, status: Optional[str] = None) -> Dict[str, Any]:
        request = exchange_query_pb.QueryBinaryMarketsRequest(status=status)
        response = await self._execute_call(call=self._stub.BinaryOptionsMarkets, request=request)

        return response

    async def fetch_trader_derivative_conditional_orders(
        self,
        subaccount_id: Optional[str] = None,
        market_id: Optional[str] = None,
    ) -> Dict[str, Any]:
        request = exchange_query_pb.QueryTraderDerivativeConditionalOrdersRequest(
            subaccount_id=subaccount_id,
            market_id=market_id,
        )
        response = await self._execute_call(call=self._stub.TraderDerivativeConditionalOrders, request=request)

        return response

    async def fetch_market_atomic_execution_fee_multiplier(
        self,
        market_id: str,
    ) -> Dict[str, Any]:
        request = exchange_query_pb.QueryMarketAtomicExecutionFeeMultiplierRequest(
            market_id=market_id,
        )
        response = await self._execute_call(call=self._stub.MarketAtomicExecutionFeeMultiplier, request=request)

        return response

    async def fetch_l3_derivative_orderbook(self, market_id: str) -> Dict[str, Any]:
        request = exchange_query_pb.QueryFullDerivativeOrderbookRequest(market_id=market_id)
        response = await self._execute_call(call=self._stub.L3DerivativeOrderBook, request=request)

        return response

    async def fetch_l3_spot_orderbook(self, market_id: str) -> Dict[str, Any]:
        request = exchange_query_pb.QueryFullSpotOrderbookRequest(market_id=market_id)
        response = await self._execute_call(call=self._stub.L3SpotOrderBook, request=request)

        return response

    async def fetch_market_balance(self, market_id: str) -> Dict[str, Any]:
        request = exchange_query_pb.QueryMarketBalanceRequest(market_id=market_id)
        response = await self._execute_call(call=self._stub.MarketBalance, request=request)

        return response

    async def fetch_market_balances(self) -> Dict[str, Any]:
        request = exchange_query_pb.QueryMarketBalancesRequest()
        response = await self._execute_call(call=self._stub.MarketBalances, request=request)

        return response

    async def fetch_denom_min_notional(self, denom: str) -> Dict[str, Any]:
        request = exchange_query_pb.QueryDenomMinNotionalRequest(denom=denom)
        response = await self._execute_call(call=self._stub.DenomMinNotional, request=request)

        return response

    async def fetch_denom_min_notionals(self) -> Dict[str, Any]:
        request = exchange_query_pb.QueryDenomMinNotionalsRequest()
        response = await self._execute_call(call=self._stub.DenomMinNotionals, request=request)
        return response

    async def fetch_active_stake_grant(self, grantee: str) -> Dict[str, Any]:
        request = exchange_query_pb.QueryActiveStakeGrantRequest(grantee=grantee)
        response = await self._execute_call(call=self._stub.ActiveStakeGrant, request=request)

        return response

    async def fetch_grant_authorization(
        self,
        granter: str,
        grantee: str,
    ) -> Dict[str, Any]:
        request = exchange_query_pb.QueryGrantAuthorizationRequest(
            granter=granter,
            grantee=grantee,
        )
        response = await self._execute_call(call=self._stub.GrantAuthorization, request=request)

        return response

    async def fetch_grant_authorizations(self, granter: str) -> Dict[str, Any]:
        request = exchange_query_pb.QueryGrantAuthorizationsRequest(granter=granter)
        response = await self._execute_call(call=self._stub.GrantAuthorizations, request=request)

        return response

    async def _execute_call(self, call: Callable, request) -> Dict[str, Any]:
        return await self._assistant.execute_call(call=call, request=request)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmwasm/wasm/v1/types.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from pyinjective.proto.amino import amino_pb2 as amino_dot_amino__pb2
from pyinjective.proto.cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1c\x63osmwasm/wasm/v1/types.proto\x12\x10\x63osmwasm.wasm.v1\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x14gogoproto/gogo.proto\x1a\x19google/protobuf/any.proto\x1a\x11\x61mino/amino.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\"]\n\x0f\x41\x63\x63\x65ssTypeParam\x12\x44\n\x05value\x18\x01 \x01(\x0e\x32\x1c.cosmwasm.wasm.v1.AccessTypeB\x10\xf2\xde\x1f\x0cyaml:\"value\"R\x05value:\x04\x98\xa0\x1f\x01\"\xa7\x01\n\x0c\x41\x63\x63\x65ssConfig\x12S\n\npermission\x18\x01 \x01(\x0e\x32\x1c.cosmwasm.wasm.v1.AccessTypeB\x15\xf2\xde\x1f\x11yaml:\"permission\"R\npermission\x12\x36\n\taddresses\x18\x03 \x03(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\taddresses:\x04\x98\xa0\x1f\x01J\x04\x08\x02\x10\x03\"\x94\x02\n\x06Params\x12t\n\x12\x63ode_upload_access\x18\x01 \x01(\x0b\x32\x1e.cosmwasm.wasm.v1.AccessConfigB&\xc8\xde\x1f\x00\xf2\xde\x1f\x19yaml:\"code_upload_access\"\xa8\xe7\xb0*\x01R\x10\x63odeUploadAccess\x12\x8d\x01\n\x1einstantiate_default_permission\x18\x02 \x01(\x0e\x32\x1c.cosmwasm.wasm.v1.AccessTypeB)\xf2\xde\x1f%yaml:\"instantiate_default_permission\"R\x1cinstantiateDefaultPermission:\x04\x98\xa0\x1f\x00\"\xc1\x01\n\x08\x43odeInfo\x12\x1b\n\tcode_hash\x18\x01 \x01(\x0cR\x08\x63odeHash\x12\x32\n\x07\x63reator\x18\x02 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\x07\x63reator\x12X\n\x12instantiate_config\x18\x05 \x01(\x0b\x32\x1e.cosmwasm.wasm.v1.AccessConfigB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01R\x11instantiateConfigJ\x04\x08\x03\x10\x04J\x04\x08\x04\x10\x05\"\x82\x03\n\x0c\x43ontractInfo\x12#\n\x07\x63ode_id\x18\x01 \x01(\x04\x42\n\xe2\xde\x1f\x06\x43odeIDR\x06\x63odeId\x12\x32\n\x07\x63reator\x18\x02 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\x07\x63reator\x12.\n\x05\x61\x64min\x18\x03 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\x05\x61\x64min\x12\x14\n\x05label\x18\x04 \x01(\tR\x05label\x12>\n\x07\x63reated\x18\x05 \x01(\x0b\x32$.cosmwasm.wasm.v1.AbsoluteTxPositionR\x07\x63reated\x12-\n\x0bibc_port_id\x18\x06 \x01(\tB\r\xe2\xde\x1f\tIBCPortIDR\tibcPortId\x12^\n\textension\x18\x07 \x01(\x0b\x32\x14.google.protobuf.AnyB*\xca\xb4-&cosmwasm.wasm.v1.ContractInfoExtensionR\textension:\x04\xe8\xa0\x1f\x01\"\x8b\x02\n\x18\x43ontractCodeHistoryEntry\x12P\n\toperation\x18\x01 \x01(\x0e\x32\x32.cosmwasm.wasm.v1.ContractCodeHistoryOperationTypeR\toperation\x12#\n\x07\x63ode_id\x18\x02 \x01(\x04\x42\n\xe2\xde\x1f\x06\x43odeIDR\x06\x63odeId\x12>\n\x07updated\x18\x03 \x01(\x0b\x32$.cosmwasm.wasm.v1.AbsoluteTxPositionR\x07updated\x12\x38\n\x03msg\x18\x04 \x01(\x0c\x42&\xfa\xde\x1f\x12RawContractMessage\x9a\xe7\xb0*\x0binline_jsonR\x03msg\"R\n\x12\x41\x62soluteTxPosition\x12!\n\x0c\x62lock_height\x18\x01 \x01(\x04R\x0b\x62lockHeight\x12\x19\n\x08tx_index\x18\x02 \x01(\x04R\x07txIndex\"e\n\x05Model\x12\x46\n\x03key\x18\x01 \x01(\x0c\x42\x34\xfa\xde\x1f\x30github.com/cometbft/cometbft/libs/bytes.HexBytesR\x03key\x12\x14\n\x05value\x18\x02 \x01(\x0cR\x05value\"\xb1\x01\n\x0f\x45ventCodeStored\x12#\n\x07\x63ode_id\x18\x01 \x01(\x04\x42\n\xe2\xde\x1f\x06\x43odeIDR\x06\x63odeId\x12\x18\n\x07\x63reator\x18\x02 \x01(\tR\x07\x63reator\x12\x43\n\raccess_config\x18\x03 \x01(\x0b\x32\x1e.cosmwasm.wasm.v1.AccessConfigR\x0c\x61\x63\x63\x65ssConfig\x12\x1a\n\x08\x63hecksum\x18\x04 \x01(\x0cR\x08\x63hecksum\"\xbe\x02\n\x19\x45ventContractInstantiated\x12)\n\x10\x63ontract_address\x18\x01 \x01(\tR\x0f\x63ontractAddress\x12\x14\n\x05\x61\x64min\x18\x02 \x01(\tR\x05\x61\x64min\x12#\n\x07\x63ode_id\x18\x03 \x01(\x04\x42\n\xe2\xde\x1f\x06\x43odeIDR\x06\x63odeId\x12\x61\n\x05\x66unds\x18\x04 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB0\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.CoinsR\x05\x66unds\x12(\n\x03msg\x18\x05 \x01(\x0c\x42\x16\xfa\xde\x1f\x12RawContractMessageR\x03msg\x12\x14\n\x05label\x18\x06 \x01(\tR\x05label\x12\x18\n\x07\x63reator\x18\x07 \x01(\tR\x07\x63reator\"\x91\x01\n\x15\x45ventContractMigrated\x12#\n\x07\x63ode_id\x18\x01 \x01(\x04\x42\n\xe2\xde\x1f\x06\x43odeIDR\x06\x63odeId\x12)\n\x10\x63ontract_address\x18\x02 \x01(\tR\x0f\x63ontractAddress\x12(\n\x03msg\x18\x03 \x01(\x0c\x42\x16\xfa\xde\x1f\x12RawContractMessageR\x03msg\"_\n\x15\x45ventContractAdminSet\x12)\n\x10\x63ontract_address\x18\x01 \x01(\tR\x0f\x63ontractAddress\x12\x1b\n\tnew_admin\x18\x02 \x01(\tR\x08newAdmin*\xf6\x01\n\nAccessType\x12\x36\n\x17\x41\x43\x43\x45SS_TYPE_UNSPECIFIED\x10\x00\x1a\x19\x8a\x9d \x15\x41\x63\x63\x65ssTypeUnspecified\x12,\n\x12\x41\x43\x43\x45SS_TYPE_NOBODY\x10\x01\x1a\x14\x8a\x9d \x10\x41\x63\x63\x65ssTypeNobody\x12\x32\n\x15\x41\x43\x43\x45SS_TYPE_EVERYBODY\x10\x03\x1a\x17\x8a\x9d \x13\x41\x63\x63\x65ssTypeEverybody\x12>\n\x1c\x41\x43\x43\x45SS_TYPE_ANY_OF_ADDRESSES\x10\x04\x1a\x1c\x8a\x9d \x18\x41\x63\x63\x65ssTypeAnyOfAddresses\x1a\x08\x88\xa3\x1e\x00\xa8\xa4\x1e\x00\"\x04\x08\x02\x10\x02*\xa6\x03\n ContractCodeHistoryOperationType\x12\x65\n0CONTRACT_CODE_HISTORY_OPERATION_TYPE_UNSPECIFIED\x10\x00\x1a/\x8a\x9d +ContractCodeHistoryOperationTypeUnspecified\x12W\n)CONTRACT_CODE_HISTORY_OPERATION_TYPE_INIT\x10\x01\x1a(\x8a\x9d $ContractCodeHistoryOperationTypeInit\x12]\n,CONTRACT_CODE_HISTORY_OPERATION_TYPE_MIGRATE\x10\x02\x1a+\x8a\x9d \'ContractCodeHistoryOperationTypeMigrate\x12]\n,CONTRACT_CODE_HISTORY_OPERATION_TYPE_GENESIS\x10\x03\x1a+\x8a\x9d \'ContractCodeHistoryOperationTypeGenesis\x1a\x04\x88\xa3\x1e\x00\x42\xb4\x01\n\x14\x63om.cosmwasm.wasm.v1B\nTypesProtoP\x01Z&github.com/CosmWasm/wasmd/x/wasm/types\xa2\x02\x03\x43WX\xaa\x02\x10\x43osmwasm.Wasm.V1\xca\x02\x10\x43osmwasm\\Wasm\\V1\xe2\x02\x1c\x43osmwasm\\Wasm\\V1\\GPBMetadata\xea\x02\x12\x43osmwasm::Wasm::V1\xc8\xe1\x1e\x00\xa8\xe2\x1e\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmwasm.wasm.v1.types_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\024com.cosmwasm.wasm.v1B\nTypesProtoP\001Z&github.com/CosmWasm/wasmd/x/wasm/types\242\002\003CWX\252\002\020Cosmwasm.Wasm.V1\312\002\020Cosmwasm\\Wasm\\V1\342\002\034Cosmwasm\\Wasm\\V1\\GPBMetadata\352\002\022Cosmwasm::Wasm::V1\310\341\036\000\250\342\036\001'
  _globals['_ACCESSTYPE']._loaded_options = None
  _globals['_ACCESSTYPE']._serialized_options = b'\210\243\036\000\250\244\036\000'
  _globals['_ACCESSTYPE'].values_by_name["ACCESS_TYPE_UNSPECIFIED"]._loaded_options = None
  _globals['_ACCESSTYPE'].values_by_name["ACCESS_TYPE_UNSPECIFIED"]._serialized_options = b'\212\235 \025AccessTypeUnspecified'
  _globals['_ACCESSTYPE'].values_by_name["ACCESS_TYPE_NOBODY"]._loaded_options = None
  _globals['_ACCESSTYPE'].values_by_name["ACCESS_TYPE_NOBODY"]._serialized_options = b'\212\235 \020AccessTypeNobody'
  _globals['_ACCESSTYPE'].values_by_name["ACCESS_TYPE_EVERYBODY"]._loaded_options = None
  _globals['_ACCESSTYPE'].values_by_name["ACCESS_TYPE_EVERYBODY"]._serialized_options = b'\212\235 \023AccessTypeEverybody'
  _globals['_ACCESSTYPE'].values_by_name["ACCESS_TYPE_ANY_OF_ADDRESSES"]._loaded_options = None
  _globals['_ACCESSTYPE'].values_by_name["ACCESS_TYPE_ANY_OF_ADDRESSES"]._serialized_options = b'\212\235 \030AccessTypeAnyOfAddresses'
  _globals['_CONTRACTCODEHISTORYOPERATIONTYPE']._loaded_options = None
  _globals['_CONTRACTCODEHISTORYOPERATIONTYPE']._serialized_options = b'\210\243\036\000'
  _globals['_CONTRACTCODEHISTORYOPERATIONTYPE'].values_by_name["CONTRACT_CODE_HISTORY_OPERATION_TYPE_UNSPECIFIED"]._loaded_options = None
  _globals['_CONTRACTCODEHISTORYOPERATIONTYPE'].values_by_name["CONTRACT_CODE_HISTORY_OPERATION_TYPE_UNSPECIFIED"]._serialized_options = b'\212\235 +ContractCodeHistoryOperationTypeUnspecified'
  _globals['_CONTRACTCODEHISTORYOPERATIONTYPE'].values_by_name["CONTRACT_CODE_HISTORY_OPERATION_TYPE_INIT"]._loaded_options = None
  _globals['_CONTRACTCODEHISTORYOPERATIONTYPE'].values_by_name["CONTRACT_CODE_HISTORY_OPERATION_TYPE_INIT"]._serialized_options = b'\212\235 $ContractCodeHistoryOperationTypeInit'
  _globals['_CONTRACTCODEHISTORYOPERATIONTYPE'].values_by_name["CONTRACT_CODE_HISTORY_OPERATION_TYPE_MIGRATE"]._loaded_options = None
  _globals['_CONTRACTCODEHISTORYOPERATIONTYPE'].values_by_name["CONTRACT_CODE_HISTORY_OPERATION_TYPE_MIGRATE"]._serialized_options = b'\212\235 \'ContractCodeHistoryOperationTypeMigrate'
  _globals['_CONTRACTCODEHISTORYOPERATIONTYPE'].values_by_name["CONTRACT_CODE_HISTORY_OPERATION_TYPE_GENESIS"]._loaded_options = None
  _globals['_CONTRACTCODEHISTORYOPERATIONTYPE'].values_by_name["CONTRACT_CODE_HISTORY_OPERATION_TYPE_GENESIS"]._serialized_options = b'\212\235 \'ContractCodeHistoryOperationTypeGenesis'
  _globals['_ACCESSTYPEPARAM'].fields_by_name['value']._loaded_options = None
  _globals['_ACCESSTYPEPARAM'].fields_by_name['value']._serialized_options = b'\362\336\037\014yaml:\"value\"'
  _globals['_ACCESSTYPEPARAM']._loaded_options = None
  _globals['_ACCESSTYPEPARAM']._serialized_options = b'\230\240\037\001'
  _globals['_ACCESSCONFIG'].fields_by_name['permission']._loaded_options = None
  _globals['_ACCESSCONFIG'].fields_by_name['permission']._serialized_options = b'\362\336\037\021yaml:\"permission\"'
  _globals['_ACCESSCONFIG'].fields_by_name['addresses']._loaded_options = None
  _globals['_ACCESSCONFIG'].fields_by_name['addresses']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_ACCESSCONFIG']._loaded_options = None
  _globals['_ACCESSCONFIG']._serialized_options = b'\230\240\037\001'
  _globals['_PARAMS'].fields_by_name['code_upload_access']._loaded_options = None
  _globals['_PARAMS'].fields_by_name['code_upload_access']._serialized_options = b'\310\336\037\000\362\336\037\031yaml:\"code_upload_access\"\250\347\260*\001'
  _globals['_PARAMS'].fields_by_name['instantiate_default_permission']._loaded_options = None
  _globals['_PARAMS'].fields_by_name['instantiate_default_permission']._serialized_options = b'\362\336\037%yaml:\"instantiate_default_permission\"'
  _globals['_PARAMS']._loaded_options = None
  _globals['_PARAMS']._serialized_options = b'\230\240\037\000'
  _globals['_CODEINFO'].fields_by_name['creator']._loaded_options = None
  _globals['_CODEINFO'].fields_by_name['creator']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_CODEINFO'].fields_by_name['instantiate_config']._loaded_options = None
  _globals['_CODEINFO'].fields_by_name['instantiate_config']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_CONTRACTINFO'].fields_by_name['code_id']._loaded_options = None
  _globals['_CONTRACTINFO'].fields_by_name['code_id']._serialized_options = b'\342\336\037\006CodeID'
  _globals['_CONTRACTINFO'].fields_by_name['creator']._loaded_options = None
  _globals['_CONTRACTINFO'].fields_by_name['creator']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_CONTRACTINFO'].fields_by_name['admin']._loaded_options = None
  _globals['_CONTRACTINFO'].fields_by_name['admin']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_CONTRACTINFO'].fields_by_name['ibc_port_id']._loaded_options = None
  _globals['_CONTRACTINFO'].fields_by_name['ibc_port_id']._serialized_options = b'\342\336\037\tIBCPortID'
  _globals['_CONTRACTINFO'].fields_by_name['extension']._loaded_options = None
  _globals['_CONTRACTINFO'].fields_by_name['extension']._serialized_options = b'\312\264-&cosmwasm.wasm.v1.ContractInfoExtension'
  _globals['_CONTRACTINFO']._loaded_options = None
  _globals['_CONTRACTINFO']._serialized_options = b'\350\240\037\001'
  _globals['_CONTRACTCODEHISTORYENTRY'].fields_by_name['code_id']._loaded_options = None
  _globals['_CONTRACTCODEHISTORYENTRY'].fields_by_name['code_id']._serialized_options = b'\342\336\037\006CodeID'
  _globals['_CONTRACTCODEHISTORYENTRY'].fields_by_name['msg']._loaded_options = None
  _globals['_CONTRACTCODEHISTORYENTRY'].fields_by_name['msg']._serialized_options = b'\372\336\037\022RawContractMessage\232\347\260*\013inline_json'
  _globals['_MODEL'].fields_by_name['key']._loaded_options = None
  _globals['_MODEL'].fields_by_name['key']._serialized_options = b'\372\336\0370github.com/cometbft/cometbft/libs/bytes.HexBytes'
  _globals['_EVENTCODESTORED'].fields_by_name['code_id']._loaded_options = None
  _globals['_EVENTCODESTORED'].fields_by_name['code_id']._serialized_options = b'\342\336\037\006CodeID'
  _globals['_EVENTCONTRACTINSTANTIATED'].fields_by_name['code_id']._loaded_options = None
  _globals['_EVENTCONTRACTINSTANTIATED'].fields_by_name['code_id']._serialized_options = b'\342\336\037\006CodeID'
  _globals['_EVENTCONTRACTINSTANTIATED'].fields_by_name['funds']._loaded_options = None
  _globals['_EVENTCONTRACTINSTANTIATED'].fields_by_name['funds']._serialized_options = b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins'
  _globals['_EVENTCONTRACTINSTANTIATED'].fields_by_name['msg']._loaded_options = None
  _globals['_EVENTCONTRACTINSTANTIATED'].fields_by_name['msg']._serialized_options = b'\372\336\037\022RawContractMessage'
  _globals['_EVENTCONTRACTMIGRATED'].fields_by_name['code_id']._loaded_options = None
  _globals['_EVENTCONTRACTMIGRATED'].fields_by_name['code_id']._serialized_options = b'\342\336\037\006CodeID'
  _globals['_EVENTCONTRACTMIGRATED'].fields_by_name['msg']._loaded_options = None
  _globals['_EVENTCONTRACTMIGRATED'].fields_by_name['msg']._serialized_options = b'\372\336\037\022RawContractMessage'
  _globals['_ACCESSTYPE']._serialized_start=2510
  _globals['_ACCESSTYPE']._serialized_end=2756
  _globals['_CONTRACTCODEHISTORYOPERATIONTYPE']._serialized_start=2759
  _globals['_CONTRACTCODEHISTORYOPERATIONTYPE']._serialized_end=3181
  _globals['_ACCESSTYPEPARAM']._serialized_start=177
  _globals['_ACCESSTYPEPARAM']._serialized_end=270
  _globals['_ACCESSCONFIG']._serialized_start=273
  _globals['_ACCESSCONFIG']._serialized_end=440
  _globals['_PARAMS']._serialized_start=443
  _globals['_PARAMS']._serialized_end=719
  _globals['_CODEINFO']._serialized_start=722
  _globals['_CODEINFO']._serialized_end=915
  _globals['_CONTRACTINFO']._serialized_start=918
  _globals['_CONTRACTINFO']._serialized_end=1304
  _globals['_CONTRACTCODEHISTORYENTRY']._serialized_start=1307
  _globals['_CONTRACTCODEHISTORYENTRY']._serialized_end=1574
  _globals['_ABSOLUTETXPOSITION']._serialized_start=1576
  _globals['_ABSOLUTETXPOSITION']._serialized_end=1658
  _globals['_MODEL']._serialized_start=1660
  _globals['_MODEL']._serialized_end=1761
  _globals['_EVENTCODESTORED']._serialized_start=1764
  _globals['_EVENTCODESTORED']._serialized_end=1941
  _globals['_EVENTCONTRACTINSTANTIATED']._serialized_start=1944
  _globals['_EVENTCONTRACTINSTANTIATED']._serialized_end=2262
  _globals['_EVENTCONTRACTMIGRATED']._serialized_start=2265
  _globals['_EVENTCONTRACTMIGRATED']._serialized_end=2410
  _globals['_EVENTCONTRACTADMINSET']._serialized_start=2412
  _globals['_EVENTCONTRACTADMINSET']._serialized_end=2507
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: exchange/injective_insurance_rpc.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&exchange/injective_insurance_rpc.proto\x12\x17injective_insurance_rpc\"\x0e\n\x0c\x46undsRequest\"M\n\rFundsResponse\x12<\n\x05\x66unds\x18\x01 \x03(\x0b\x32&.injective_insurance_rpc.InsuranceFundR\x05\x66unds\"\xf5\x03\n\rInsuranceFund\x12#\n\rmarket_ticker\x18\x01 \x01(\tR\x0cmarketTicker\x12\x1b\n\tmarket_id\x18\x02 \x01(\tR\x08marketId\x12#\n\rdeposit_denom\x18\x03 \x01(\tR\x0c\x64\x65positDenom\x12(\n\x10pool_token_denom\x18\x04 \x01(\tR\x0epoolTokenDenom\x12I\n!redemption_notice_period_duration\x18\x05 \x01(\x12R\x1eredemptionNoticePeriodDuration\x12\x18\n\x07\x62\x61lance\x18\x06 \x01(\tR\x07\x62\x61lance\x12\x1f\n\x0btotal_share\x18\x07 \x01(\tR\ntotalShare\x12\x1f\n\x0boracle_base\x18\x08 \x01(\tR\noracleBase\x12!\n\x0coracle_quote\x18\t \x01(\tR\x0boracleQuote\x12\x1f\n\x0boracle_type\x18\n \x01(\tR\noracleType\x12\x16\n\x06\x65xpiry\x18\x0b \x01(\x12R\x06\x65xpiry\x12P\n\x12\x64\x65posit_token_meta\x18\x0c \x01(\x0b\x32\".injective_insurance_rpc.TokenMetaR\x10\x64\x65positTokenMeta\"\xa0\x01\n\tTokenMeta\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x18\n\x07\x61\x64\x64ress\x18\x02 \x01(\tR\x07\x61\x64\x64ress\x12\x16\n\x06symbol\x18\x03 \x01(\tR\x06symbol\x12\x12\n\x04logo\x18\x04 \x01(\tR\x04logo\x12\x1a\n\x08\x64\x65\x63imals\x18\x05 \x01(\x11R\x08\x64\x65\x63imals\x12\x1d\n\nupdated_at\x18\x06 \x01(\x12R\tupdatedAt\"#\n\x0b\x46undRequest\x12\x14\n\x05\x64\x65nom\x18\x01 \x01(\tR\x05\x64\x65nom\"J\n\x0c\x46undResponse\x12:\n\x04\x66und\x18\x01 \x01(\x0b\x32&.injective_insurance_rpc.InsuranceFundR\x04\x66und\"s\n\x12RedemptionsRequest\x12\x1a\n\x08redeemer\x18\x01 \x01(\tR\x08redeemer\x12)\n\x10redemption_denom\x18\x02 \x01(\tR\x0fredemptionDenom\x12\x16\n\x06status\x18\x03 \x01(\tR\x06status\"u\n\x13RedemptionsResponse\x12^\n\x14redemption_schedules\x18\x01 \x03(\x0b\x32+.injective_insurance_rpc.RedemptionScheduleR\x13redemptionSchedules\"\x9b\x03\n\x12RedemptionSchedule\x12#\n\rredemption_id\x18\x01 \x01(\x04R\x0credemptionId\x12\x16\n\x06status\x18\x02 \x01(\tR\x06status\x12\x1a\n\x08redeemer\x18\x03 \x01(\tR\x08redeemer\x12:\n\x19\x63laimable_redemption_time\x18\x04 \x01(\x12R\x17\x63laimableRedemptionTime\x12+\n\x11redemption_amount\x18\x05 \x01(\tR\x10redemptionAmount\x12)\n\x10redemption_denom\x18\x06 \x01(\tR\x0fredemptionDenom\x12!\n\x0crequested_at\x18\x07 \x01(\x12R\x0brequestedAt\x12)\n\x10\x64isbursed_amount\x18\x08 \x01(\tR\x0f\x64isbursedAmount\x12\'\n\x0f\x64isbursed_denom\x18\t \x01(\tR\x0e\x64isbursedDenom\x12!\n\x0c\x64isbursed_at\x18\n \x01(\x12R\x0b\x64isbursedAt2\xae\x02\n\x15InjectiveInsuranceRPC\x12V\n\x05\x46unds\x12%.injective_insurance_rpc.FundsRequest\x1a&.injective_insurance_rpc.FundsResponse\x12S\n\x04\x46und\x12$.injective_insurance_rpc.FundRequest\x1a%.injective_insurance_rpc.FundResponse\x12h\n\x0bRedemptions\x12+.injective_insurance_rpc.RedemptionsRequest\x1a,.injective_insurance_rpc.RedemptionsResponseB\xc9\x01\n\x1b\x63om.injective_insurance_rpcB\x1aInjectiveInsuranceRpcProtoP\x01Z\x1a/injective_insurance_rpcpb\xa2\x02\x03IXX\xaa\x02\x15InjectiveInsuranceRpc\xca\x02\x15InjectiveInsuranceRpc\xe2\x02!InjectiveInsuranceRpc\\GPBMetadata\xea\x02\x15InjectiveInsuranceRpcb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'exchange.injective_insurance_rpc_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\033com.injective_insurance_rpcB\032InjectiveInsuranceRpcProtoP\001Z\032/injective_insurance_rpcpb\242\002\003IXX\252\002\025InjectiveInsuranceRpc\312\002\025InjectiveInsuranceRpc\342\002!InjectiveInsuranceRpc\\GPBMetadata\352\002\025InjectiveInsuranceRpc'
  _globals['_FUNDSREQUEST']._serialized_start=67
  _globals['_FUNDSREQUEST']._serialized_end=81
  _globals['_FUNDSRESPONSE']._serialized_start=83
  _globals['_FUNDSRESPONSE']._serialized_end=160
  _globals['_INSURANCEFUND']._serialized_start=163
  _globals['_INSURANCEFUND']._serialized_end=664
  _globals['_TOKENMETA']._serialized_start=667
  _globals['_TOKENMETA']._serialized_end=827
  _globals['_FUNDREQUEST']._serialized_start=829
  _globals['_FUNDREQUEST']._serialized_end=864
  _globals['_FUNDRESPONSE']._serialized_start=866
  _globals['_FUNDRESPONSE']._serialized_end=940
  _globals['_REDEMPTIONSREQUEST']._serialized_start=942
  _globals['_REDEMPTIONSREQUEST']._serialized_end=1057
  _globals['_REDEMPTIONSRESPONSE']._serialized_start=1059
  _globals['_REDEMPTIONSRESPONSE']._serialized_end=1176
  _globals['_REDEMPTIONSCHEDULE']._serialized_start=1179
  _globals['_REDEMPTIONSCHEDULE']._serialized_end=1590
  _globals['_INJECTIVEINSURANCERPC']._serialized_start=1593
  _globals['_INJECTIVEINSURANCERPC']._serialized_end=1895
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: exchange/injective_portfolio_rpc.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&exchange/injective_portfolio_rpc.proto\x12\x17injective_portfolio_rpc\"Y\n\x13TokenHoldersRequest\x12\x14\n\x05\x64\x65nom\x18\x01 \x01(\tR\x05\x64\x65nom\x12\x16\n\x06\x63ursor\x18\x02 \x01(\tR\x06\x63ursor\x12\x14\n\x05limit\x18\x03 \x01(\x11R\x05limit\"t\n\x14TokenHoldersResponse\x12\x39\n\x07holders\x18\x01 \x03(\x0b\x32\x1f.injective_portfolio_rpc.HolderR\x07holders\x12!\n\x0cnext_cursors\x18\x02 \x03(\tR\x0bnextCursors\"K\n\x06Holder\x12\'\n\x0f\x61\x63\x63ount_address\x18\x01 \x01(\tR\x0e\x61\x63\x63ountAddress\x12\x18\n\x07\x62\x61lance\x18\x02 \x01(\tR\x07\x62\x61lance\"B\n\x17\x41\x63\x63ountPortfolioRequest\x12\'\n\x0f\x61\x63\x63ount_address\x18\x01 \x01(\tR\x0e\x61\x63\x63ountAddress\"\\\n\x18\x41\x63\x63ountPortfolioResponse\x12@\n\tportfolio\x18\x01 \x01(\x0b\x32\".injective_portfolio_rpc.PortfolioR\tportfolio\"\xa4\x02\n\tPortfolio\x12\'\n\x0f\x61\x63\x63ount_address\x18\x01 \x01(\tR\x0e\x61\x63\x63ountAddress\x12\x42\n\rbank_balances\x18\x02 \x03(\x0b\x32\x1d.injective_portfolio_rpc.CoinR\x0c\x62\x61nkBalances\x12N\n\x0bsubaccounts\x18\x03 \x03(\x0b\x32,.injective_portfolio_rpc.SubaccountBalanceV2R\x0bsubaccounts\x12Z\n\x13positions_with_upnl\x18\x04 \x03(\x0b\x32*.injective_portfolio_rpc.PositionsWithUPNLR\x11positionsWithUpnl\"Q\n\x04\x43oin\x12\x14\n\x05\x64\x65nom\x18\x01 \x01(\tR\x05\x64\x65nom\x12\x16\n\x06\x61mount\x18\x02 \x01(\tR\x06\x61mount\x12\x1b\n\tusd_value\x18\x03 \x01(\tR\x08usdValue\"\x96\x01\n\x13SubaccountBalanceV2\x12#\n\rsubaccount_id\x18\x01 \x01(\tR\x0csubaccountId\x12\x14\n\x05\x64\x65nom\x18\x02 \x01(\tR\x05\x64\x65nom\x12\x44\n\x07\x64\x65posit\x18\x03 \x01(\x0b\x32*.injective_portfolio_rpc.SubaccountDepositR\x07\x64\x65posit\"\xc5\x01\n\x11SubaccountDeposit\x12#\n\rtotal_balance\x18\x01 \x01(\tR\x0ctotalBalance\x12+\n\x11\x61vailable_balance\x18\x02 \x01(\tR\x10\x61vailableBalance\x12*\n\x11total_balance_usd\x18\x03 \x01(\tR\x0ftotalBalanceUsd\x12\x32\n\x15\x61vailable_balance_usd\x18\x04 \x01(\tR\x13\x61vailableBalanceUsd\"\x83\x01\n\x11PositionsWithUPNL\x12G\n\x08position\x18\x01 \x01(\x0b\x32+.injective_portfolio_rpc.DerivativePositionR\x08position\x12%\n\x0eunrealized_pnl\x18\x02 \x01(\tR\runrealizedPnl\"\xb0\x03\n\x12\x44\x65rivativePosition\x12\x16\n\x06ticker\x18\x01 \x01(\tR\x06ticker\x12\x1b\n\tmarket_id\x18\x02 \x01(\tR\x08marketId\x12#\n\rsubaccount_id\x18\x03 \x01(\tR\x0csubaccountId\x12\x1c\n\tdirection\x18\x04 \x01(\tR\tdirection\x12\x1a\n\x08quantity\x18\x05 \x01(\tR\x08quantity\x12\x1f\n\x0b\x65ntry_price\x18\x06 \x01(\tR\nentryPrice\x12\x16\n\x06margin\x18\x07 \x01(\tR\x06margin\x12+\n\x11liquidation_price\x18\x08 \x01(\tR\x10liquidationPrice\x12\x1d\n\nmark_price\x18\t \x01(\tR\tmarkPrice\x12\x43\n\x1e\x61ggregate_reduce_only_quantity\x18\x0b \x01(\tR\x1b\x61ggregateReduceOnlyQuantity\x12\x1d\n\nupdated_at\x18\x0c \x01(\x12R\tupdatedAt\x12\x1d\n\ncreated_at\x18\r \x01(\x12R\tcreatedAt\"\\\n\x1f\x41\x63\x63ountPortfolioBalancesRequest\x12\'\n\x0f\x61\x63\x63ount_address\x18\x01 \x01(\tR\x0e\x61\x63\x63ountAddress\x12\x10\n\x03usd\x18\x02 \x01(\x08R\x03usd\"l\n AccountPortfolioBalancesResponse\x12H\n\tportfolio\x18\x01 \x01(\x0b\x32*.injective_portfolio_rpc.PortfolioBalancesR\tportfolio\"\xed\x01\n\x11PortfolioBalances\x12\'\n\x0f\x61\x63\x63ount_address\x18\x01 \x01(\tR\x0e\x61\x63\x63ountAddress\x12\x42\n\rbank_balances\x18\x02 \x03(\x0b\x32\x1d.injective_portfolio_rpc.CoinR\x0c\x62\x61nkBalances\x12N\n\x0bsubaccounts\x18\x03 \x03(\x0b\x32,.injective_portfolio_rpc.SubaccountBalanceV2R\x0bsubaccounts\x12\x1b\n\ttotal_usd\x18\x04 \x01(\tR\x08totalUsd\"\x81\x01\n\x1dStreamAccountPortfolioRequest\x12\'\n\x0f\x61\x63\x63ount_address\x18\x01 \x01(\tR\x0e\x61\x63\x63ountAddress\x12#\n\rsubaccount_id\x18\x02 \x01(\tR\x0csubaccountId\x12\x12\n\x04type\x18\x03 \x01(\tR\x04type\"\xa5\x01\n\x1eStreamAccountPortfolioResponse\x12\x12\n\x04type\x18\x01 \x01(\tR\x04type\x12\x14\n\x05\x64\x65nom\x18\x02 \x01(\tR\x05\x64\x65nom\x12\x16\n\x06\x61mount\x18\x03 \x01(\tR\x06\x61mount\x12#\n\rsubaccount_id\x18\x04 \x01(\tR\x0csubaccountId\x12\x1c\n\ttimestamp\x18\x05 \x01(\x12R\ttimestamp2\x9d\x04\n\x15InjectivePortfolioRPC\x12k\n\x0cTokenHolders\x12,.injective_portfolio_rpc.TokenHoldersRequest\x1a-.injective_portfolio_rpc.TokenHoldersResponse\x12w\n\x10\x41\x63\x63ountPortfolio\x12\x30.injective_portfolio_rpc.AccountPortfolioRequest\x1a\x31.injective_portfolio_rpc.AccountPortfolioResponse\x12\x8f\x01\n\x18\x41\x63\x63ountPortfolioBalances\x12\x38.injective_portfolio_rpc.AccountPortfolioBalancesRequest\x1a\x39.injective_portfolio_rpc.AccountPortfolioBalancesResponse\x12\x8b\x01\n\x16StreamAccountPortfolio\x12\x36.injective_portfolio_rpc.StreamAccountPortfolioRequest\x1a\x37.injective_portfolio_rpc.StreamAccountPortfolioResponse0\x01\x42\xc9\x01\n\x1b\x63om.injective_portfolio_rpcB\x1aInjectivePortfolioRpcProtoP\x01Z\x1a/injective_portfolio_rpcpb\xa2\x02\x03IXX\xaa\x02\x15InjectivePortfolioRpc\xca\x02\x15InjectivePortfolioRpc\xe2\x02!InjectivePortfolioRpc\\GPBMetadata\xea\x02\x15InjectivePortfolioRpcb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'exchange.injective_portfolio_rpc_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\033com.injective_portfolio_rpcB\032InjectivePortfolioRpcProtoP\001Z\032/injective_portfolio_rpcpb\242\002\003IXX\252\002\025InjectivePortfolioRpc\312\002\025InjectivePortfolioRpc\342\002!InjectivePortfolioRpc\\GPBMetadata\352\002\025InjectivePortfolioRpc'
  _globals['_TOKENHOLDERSREQUEST']._serialized_start=67
  _globals['_TOKENHOLDERSREQUEST']._serialized_end=156
  _globals['_TOKENHOLDERSRESPONSE']._serialized_start=158
  _globals['_TOKENHOLDERSRESPONSE']._serialized_end=274
  _globals['_HOLDER']._serialized_start=276
  _globals['_HOLDER']._serialized_end=351
  _globals['_ACCOUNTPORTFOLIOREQUEST']._serialized_start=353
  _globals['_ACCOUNTPORTFOLIOREQUEST']._serialized_end=419
  _globals['_ACCOUNTPORTFOLIORESPONSE']._serialized_start=421
  _globals['_ACCOUNTPORTFOLIORESPONSE']._serialized_end=513
  _globals['_PORTFOLIO']._serialized_start=516
  _globals['_PORTFOLIO']._serialized_end=808
  _globals['_COIN']._serialized_start=810
  _globals['_COIN']._serialized_end=891
  _globals['_SUBACCOUNTBALANCEV2']._serialized_start=894
  _globals['_SUBACCOUNTBALANCEV2']._serialized_end=1044
  _globals['_SUBACCOUNTDEPOSIT']._serialized_start=1047
  _globals['_SUBACCOUNTDEPOSIT']._serialized_end=1244
  _globals['_POSITIONSWITHUPNL']._serialized_start=1247
  _globals['_POSITIONSWITHUPNL']._serialized_end=1378
  _globals['_DERIVATIVEPOSITION']._serialized_start=1381
  _globals['_DERIVATIVEPOSITION']._serialized_end=1813
  _globals['_ACCOUNTPORTFOLIOBALANCESREQUEST']._serialized_start=1815
  _globals['_ACCOUNTPORTFOLIOBALANCESREQUEST']._serialized_end=1907
  _globals['_ACCOUNTPORTFOLIOBALANCESRESPONSE']._serialized_start=1909
  _globals['_ACCOUNTPORTFOLIOBALANCESRESPONSE']._serialized_end=2017
  _globals['_PORTFOLIOBALANCES']._serialized_start=2020
  _globals['_PORTFOLIOBALANCES']._serialized_end=2257
  _globals['_STREAMACCOUNTPORTFOLIOREQUEST']._serialized_start=2260
  _globals['_STREAMACCOUNTPORTFOLIOREQUEST']._serialized_end=2389
  _globals['_STREAMACCOUNTPORTFOLIORESPONSE']._serialized_start=2392
  _globals['_STREAMACCOUNTPORTFOLIORESPONSE']._serialized_end=2557
  _globals['_INJECTIVEPORTFOLIORPC']._serialized_start=2560
  _globals['_INJECTIVEPORTFOLIORPC']._serialized_end=3101
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmwasm/wasm/v1/ibc.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1a\x63osmwasm/wasm/v1/ibc.proto\x12\x10\x63osmwasm.wasm.v1\x1a\x14gogoproto/gogo.proto\"\xe2\x01\n\nMsgIBCSend\x12\x33\n\x07\x63hannel\x18\x02 \x01(\tB\x19\xf2\xde\x1f\x15yaml:\"source_channel\"R\x07\x63hannel\x12@\n\x0etimeout_height\x18\x04 \x01(\x04\x42\x19\xf2\xde\x1f\x15yaml:\"timeout_height\"R\rtimeoutHeight\x12I\n\x11timeout_timestamp\x18\x05 \x01(\x04\x42\x1c\xf2\xde\x1f\x18yaml:\"timeout_timestamp\"R\x10timeoutTimestamp\x12\x12\n\x04\x64\x61ta\x18\x06 \x01(\x0cR\x04\x64\x61ta\"0\n\x12MsgIBCSendResponse\x12\x1a\n\x08sequence\x18\x01 \x01(\x04R\x08sequence\"$\n\"MsgIBCWriteAcknowledgementResponse\"I\n\x12MsgIBCCloseChannel\x12\x33\n\x07\x63hannel\x18\x02 \x01(\tB\x19\xf2\xde\x1f\x15yaml:\"source_channel\"R\x07\x63hannelB\xae\x01\n\x14\x63om.cosmwasm.wasm.v1B\x08IbcProtoP\x01Z&github.com/CosmWasm/wasmd/x/wasm/types\xa2\x02\x03\x43WX\xaa\x02\x10\x43osmwasm.Wasm.V1\xca\x02\x10\x43osmwasm\\Wasm\\V1\xe2\x02\x1c\x43osmwasm\\Wasm\\V1\\GPBMetadata\xea\x02\x12\x43osmwasm::Wasm::V1\xc8\xe1\x1e\x00\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmwasm.wasm.v1.ibc_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\024com.cosmwasm.wasm.v1B\010IbcProtoP\001Z&github.com/CosmWasm/wasmd/x/wasm/types\242\002\003CWX\252\002\020Cosmwasm.Wasm.V1\312\002\020Cosmwasm\\Wasm\\V1\342\002\034Cosmwasm\\Wasm\\V1\\GPBMetadata\352\002\022Cosmwasm::Wasm::V1\310\341\036\000'
  _globals['_MSGIBCSEND'].fields_by_name['channel']._loaded_options = None
  _globals['_MSGIBCSEND'].fields_by_name['channel']._serialized_options = b'\362\336\037\025yaml:\"source_channel\"'
  _globals['_MSGIBCSEND'].fields_by_name['timeout_height']._loaded_options = None
  _globals['_MSGIBCSEND'].fields_by_name['timeout_height']._serialized_options = b'\362\336\037\025yaml:\"timeout_height\"'
  _globals['_MSGIBCSEND'].fields_by_name['timeout_timestamp']._loaded_options = None
  _globals['_MSGIBCSEND'].fields_by_name['timeout_timestamp']._serialized_options = b'\362\336\037\030yaml:\"timeout_timestamp\"'
  _globals['_MSGIBCCLOSECHANNEL'].fields_by_name['channel']._loaded_options = None
  _globals['_MSGIBCCLOSECHANNEL'].fields_by_name['channel']._serialized_options = b'\362\336\037\025yaml:\"source_channel\"'
  _globals['_MSGIBCSEND']._serialized_start=71
  _globals['_MSGIBCSEND']._serialized_end=297
  _globals['_MSGIBCSENDRESPONSE']._serialized_start=299
  _globals['_MSGIBCSENDRESPONSE']._serialized_end=347
  _globals['_MSGIBCWRITEACKNOWLEDGEMENTRESPONSE']._serialized_start=349
  _globals['_MSGIBCWRITEACKNOWLEDGEMENTRESPONSE']._serialized_end=385
  _globals['_MSGIBCCLOSECHANNEL']._serialized_start=387
  _globals['_MSGIBCCLOSECHANNEL']._serialized_end=460
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cometbft/abci/v1beta3/types.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.cometbft.abci.v1beta1 import types_pb2 as cometbft_dot_abci_dot_v1beta1_dot_types__pb2
from pyinjective.proto.cometbft.abci.v1beta2 import types_pb2 as cometbft_dot_abci_dot_v1beta2_dot_types__pb2
from pyinjective.proto.cometbft.types.v1 import params_pb2 as cometbft_dot_types_dot_v1_dot_params__pb2
from pyinjective.proto.cometbft.types.v1beta1 import validator_pb2 as cometbft_dot_types_dot_v1beta1_dot_validator__pb2
from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!cometbft/abci/v1beta3/types.proto\x12\x15\x63ometbft.abci.v1beta3\x1a!cometbft/abci/v1beta1/types.proto\x1a!cometbft/abci/v1beta2/types.proto\x1a\x1e\x63ometbft/types/v1/params.proto\x1a&cometbft/types/v1beta1/validator.proto\x1a\x14gogoproto/gogo.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\x9f\n\n\x07Request\x12\x38\n\x04\x65\x63ho\x18\x01 \x01(\x0b\x32\".cometbft.abci.v1beta1.RequestEchoH\x00R\x04\x65\x63ho\x12;\n\x05\x66lush\x18\x02 \x01(\x0b\x32#.cometbft.abci.v1beta1.RequestFlushH\x00R\x05\x66lush\x12\x38\n\x04info\x18\x03 \x01(\x0b\x32\".cometbft.abci.v1beta2.RequestInfoH\x00R\x04info\x12H\n\ninit_chain\x18\x05 \x01(\x0b\x32\'.cometbft.abci.v1beta3.RequestInitChainH\x00R\tinitChain\x12;\n\x05query\x18\x06 \x01(\x0b\x32#.cometbft.abci.v1beta1.RequestQueryH\x00R\x05query\x12\x42\n\x08\x63heck_tx\x18\x08 \x01(\x0b\x32%.cometbft.abci.v1beta1.RequestCheckTxH\x00R\x07\x63heckTx\x12>\n\x06\x63ommit\x18\x0b \x01(\x0b\x32$.cometbft.abci.v1beta1.RequestCommitH\x00R\x06\x63ommit\x12T\n\x0elist_snapshots\x18\x0c \x01(\x0b\x32+.cometbft.abci.v1beta1.RequestListSnapshotsH\x00R\rlistSnapshots\x12T\n\x0eoffer_snapshot\x18\r \x01(\x0b\x32+.cometbft.abci.v1beta1.RequestOfferSnapshotH\x00R\rofferSnapshot\x12\x61\n\x13load_snapshot_chunk\x18\x0e \x01(\x0b\x32/.cometbft.abci.v1beta1.RequestLoadSnapshotChunkH\x00R\x11loadSnapshotChunk\x12\x64\n\x14\x61pply_snapshot_chunk\x18\x0f \x01(\x0b\x32\x30.cometbft.abci.v1beta1.RequestApplySnapshotChunkH\x00R\x12\x61pplySnapshotChunk\x12Z\n\x10prepare_proposal\x18\x10 \x01(\x0b\x32-.cometbft.abci.v1beta3.RequestPrepareProposalH\x00R\x0fprepareProposal\x12Z\n\x10process_proposal\x18\x11 \x01(\x0b\x32-.cometbft.abci.v1beta3.RequestProcessProposalH\x00R\x0fprocessProposal\x12K\n\x0b\x65xtend_vote\x18\x12 \x01(\x0b\x32(.cometbft.abci.v1beta3.RequestExtendVoteH\x00R\nextendVote\x12g\n\x15verify_vote_extension\x18\x13 \x01(\x0b\x32\x31.cometbft.abci.v1beta3.RequestVerifyVoteExtensionH\x00R\x13verifyVoteExtension\x12T\n\x0e\x66inalize_block\x18\x14 \x01(\x0b\x32+.cometbft.abci.v1beta3.RequestFinalizeBlockH\x00R\rfinalizeBlockB\x07\n\x05valueJ\x04\x08\x04\x10\x05J\x04\x08\x07\x10\x08J\x04\x08\t\x10\nJ\x04\x08\n\x10\x0b\"\xd3\x02\n\x10RequestInitChain\x12\x38\n\x04time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x08\xc8\xde\x1f\x00\x90\xdf\x1f\x01R\x04time\x12\x19\n\x08\x63hain_id\x18\x02 \x01(\tR\x07\x63hainId\x12M\n\x10\x63onsensus_params\x18\x03 \x01(\x0b\x32\".cometbft.types.v1.ConsensusParamsR\x0f\x63onsensusParams\x12L\n\nvalidators\x18\x04 \x03(\x0b\x32&.cometbft.abci.v1beta1.ValidatorUpdateB\x04\xc8\xde\x1f\x00R\nvalidators\x12&\n\x0f\x61pp_state_bytes\x18\x05 \x01(\x0cR\rappStateBytes\x12%\n\x0einitial_height\x18\x06 \x01(\x03R\rinitialHeight\"\xa4\x03\n\x16RequestPrepareProposal\x12 \n\x0cmax_tx_bytes\x18\x01 \x01(\x03R\nmaxTxBytes\x12\x10\n\x03txs\x18\x02 \x03(\x0cR\x03txs\x12[\n\x11local_last_commit\x18\x03 \x01(\x0b\x32).cometbft.abci.v1beta3.ExtendedCommitInfoB\x04\xc8\xde\x1f\x00R\x0flocalLastCommit\x12J\n\x0bmisbehavior\x18\x04 \x03(\x0b\x32\".cometbft.abci.v1beta2.MisbehaviorB\x04\xc8\xde\x1f\x00R\x0bmisbehavior\x12\x16\n\x06height\x18\x05 \x01(\x03R\x06height\x12\x38\n\x04time\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x08\xc8\xde\x1f\x00\x90\xdf\x1f\x01R\x04time\x12\x30\n\x14next_validators_hash\x18\x07 \x01(\x0cR\x12nextValidatorsHash\x12)\n\x10proposer_address\x18\x08 \x01(\x0cR\x0fproposerAddress\"\x94\x03\n\x16RequestProcessProposal\x12\x10\n\x03txs\x18\x01 \x03(\x0cR\x03txs\x12Y\n\x14proposed_last_commit\x18\x02 \x01(\x0b\x32!.cometbft.abci.v1beta3.CommitInfoB\x04\xc8\xde\x1f\x00R\x12proposedLastCommit\x12J\n\x0bmisbehavior\x18\x03 \x03(\x0b\x32\".cometbft.abci.v1beta2.MisbehaviorB\x04\xc8\xde\x1f\x00R\x0bmisbehavior\x12\x12\n\x04hash\x18\x04 \x01(\x0cR\x04hash\x12\x16\n\x06height\x18\x05 \x01(\x03R\x06height\x12\x38\n\x04time\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x08\xc8\xde\x1f\x00\x90\xdf\x1f\x01R\x04time\x12\x30\n\x14next_validators_hash\x18\x07 \x01(\x0cR\x12nextValidatorsHash\x12)\n\x10proposer_address\x18\x08 \x01(\x0cR\x0fproposerAddress\"\x8f\x03\n\x11RequestExtendVote\x12\x12\n\x04hash\x18\x01 \x01(\x0cR\x04hash\x12\x16\n\x06height\x18\x02 \x01(\x03R\x06height\x12\x38\n\x04time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x08\xc8\xde\x1f\x00\x90\xdf\x1f\x01R\x04time\x12\x10\n\x03txs\x18\x04 \x03(\x0cR\x03txs\x12Y\n\x14proposed_last_commit\x18\x05 \x01(\x0b\x32!.cometbft.abci.v1beta3.CommitInfoB\x04\xc8\xde\x1f\x00R\x12proposedLastCommit\x12J\n\x0bmisbehavior\x18\x06 \x03(\x0b\x32\".cometbft.abci.v1beta2.MisbehaviorB\x04\xc8\xde\x1f\x00R\x0bmisbehavior\x12\x30\n\x14next_validators_hash\x18\x07 \x01(\x0cR\x12nextValidatorsHash\x12)\n\x10proposer_address\x18\x08 \x01(\x0cR\x0fproposerAddress\"\x9c\x01\n\x1aRequestVerifyVoteExtension\x12\x12\n\x04hash\x18\x01 \x01(\x0cR\x04hash\x12+\n\x11validator_address\x18\x02 \x01(\x0cR\x10validatorAddress\x12\x16\n\x06height\x18\x03 \x01(\x03R\x06height\x12%\n\x0evote_extension\x18\x04 \x01(\x0cR\rvoteExtension\"\x90\x03\n\x14RequestFinalizeBlock\x12\x10\n\x03txs\x18\x01 \x03(\x0cR\x03txs\x12W\n\x13\x64\x65\x63ided_last_commit\x18\x02 \x01(\x0b\x32!.cometbft.abci.v1beta3.CommitInfoB\x04\xc8\xde\x1f\x00R\x11\x64\x65\x63idedLastCommit\x12J\n\x0bmisbehavior\x18\x03 \x03(\x0b\x32\".cometbft.abci.v1beta2.MisbehaviorB\x04\xc8\xde\x1f\x00R\x0bmisbehavior\x12\x12\n\x04hash\x18\x04 \x01(\x0cR\x04hash\x12\x16\n\x06height\x18\x05 \x01(\x03R\x06height\x12\x38\n\x04time\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x08\xc8\xde\x1f\x00\x90\xdf\x1f\x01R\x04time\x12\x30\n\x14next_validators_hash\x18\x07 \x01(\x0cR\x12nextValidatorsHash\x12)\n\x10proposer_address\x18\x08 \x01(\x0cR\x0fproposerAddress\"\xfa\n\n\x08Response\x12H\n\texception\x18\x01 \x01(\x0b\x32(.cometbft.abci.v1beta1.ResponseExceptionH\x00R\texception\x12\x39\n\x04\x65\x63ho\x18\x02 \x01(\x0b\x32#.cometbft.abci.v1beta1.ResponseEchoH\x00R\x04\x65\x63ho\x12<\n\x05\x66lush\x18\x03 \x01(\x0b\x32$.cometbft.abci.v1beta1.ResponseFlushH\x00R\x05\x66lush\x12\x39\n\x04info\x18\x04 \x01(\x0b\x32#.cometbft.abci.v1beta1.ResponseInfoH\x00R\x04info\x12I\n\ninit_chain\x18\x06 \x01(\x0b\x32(.cometbft.abci.v1beta3.ResponseInitChainH\x00R\tinitChain\x12<\n\x05query\x18\x07 \x01(\x0b\x32$.cometbft.abci.v1beta1.ResponseQueryH\x00R\x05query\x12\x43\n\x08\x63heck_tx\x18\t \x01(\x0b\x32&.cometbft.abci.v1beta3.ResponseCheckTxH\x00R\x07\x63heckTx\x12?\n\x06\x63ommit\x18\x0c \x01(\x0b\x32%.cometbft.abci.v1beta3.ResponseCommitH\x00R\x06\x63ommit\x12U\n\x0elist_snapshots\x18\r \x01(\x0b\x32,.cometbft.abci.v1beta1.ResponseListSnapshotsH\x00R\rlistSnapshots\x12U\n\x0eoffer_snapshot\x18\x0e \x01(\x0b\x32,.cometbft.abci.v1beta1.ResponseOfferSnapshotH\x00R\rofferSnapshot\x12\x62\n\x13load_snapshot_chunk\x18\x0f \x01(\x0b\x32\x30.cometbft.abci.v1beta1.ResponseLoadSnapshotChunkH\x00R\x11loadSnapshotChunk\x12\x65\n\x14\x61pply_snapshot_chunk\x18\x10 \x01(\x0b\x32\x31.cometbft.abci.v1beta1.ResponseApplySnapshotChunkH\x00R\x12\x61pplySnapshotChunk\x12[\n\x10prepare_proposal\x18\x11 \x01(\x0b\x32..cometbft.abci.v1beta2.ResponsePrepareProposalH\x00R\x0fprepareProposal\x12[\n\x10process_proposal\x18\x12 \x01(\x0b\x32..cometbft.abci.v1beta2.ResponseProcessProposalH\x00R\x0fprocessProposal\x12L\n\x0b\x65xtend_vote\x18\x13 \x01(\x0b\x32).cometbft.abci.v1beta3.ResponseExtendVoteH\x00R\nextendVote\x12h\n\x15verify_vote_extension\x18\x14 \x01(\x0b\x32\x32.cometbft.abci.v1beta3.ResponseVerifyVoteExtensionH\x00R\x13verifyVoteExtension\x12U\n\x0e\x66inalize_block\x18\x15 \x01(\x0b\x32,.cometbft.abci.v1beta3.ResponseFinalizeBlockH\x00R\rfinalizeBlockB\x07\n\x05valueJ\x04\x08\x05\x10\x06J\x04\x08\x08\x10\tJ\x04\x08\n\x10\x0bJ\x04\x08\x0b\x10\x0c\"\xcb\x01\n\x11ResponseInitChain\x12M\n\x10\x63onsensus_params\x18\x01 \x01(\x0b\x32\".cometbft.types.v1.ConsensusParamsR\x0f\x63onsensusParams\x12L\n\nvalidators\x18\x02 \x03(\x0b\x32&.cometbft.abci.v1beta1.ValidatorUpdateB\x04\xc8\xde\x1f\x00R\nvalidators\x12\x19\n\x08\x61pp_hash\x18\x03 \x01(\x0cR\x07\x61ppHash\"\xb0\x02\n\x0fResponseCheckTx\x12\x12\n\x04\x63ode\x18\x01 \x01(\rR\x04\x63ode\x12\x12\n\x04\x64\x61ta\x18\x02 \x01(\x0cR\x04\x64\x61ta\x12\x10\n\x03log\x18\x03 \x01(\tR\x03log\x12\x12\n\x04info\x18\x04 \x01(\tR\x04info\x12\x1e\n\ngas_wanted\x18\x05 \x01(\x03R\ngas_wanted\x12\x1a\n\x08gas_used\x18\x06 \x01(\x03R\x08gas_used\x12N\n\x06\x65vents\x18\x07 \x03(\x0b\x32\x1c.cometbft.abci.v1beta2.EventB\x18\xc8\xde\x1f\x00\xea\xde\x1f\x10\x65vents,omitemptyR\x06\x65vents\x12\x1c\n\tcodespace\x18\x08 \x01(\tR\tcodespaceJ\x04\x08\t\x10\x0cR\x06senderR\x08priorityR\rmempool_error\"A\n\x0eResponseCommit\x12#\n\rretain_height\x18\x03 \x01(\x03R\x0cretainHeightJ\x04\x08\x01\x10\x02J\x04\x08\x02\x10\x03\";\n\x12ResponseExtendVote\x12%\n\x0evote_extension\x18\x01 \x01(\x0cR\rvoteExtension\"\xab\x01\n\x1bResponseVerifyVoteExtension\x12W\n\x06status\x18\x01 \x01(\x0e\x32?.cometbft.abci.v1beta3.ResponseVerifyVoteExtension.VerifyStatusR\x06status\"3\n\x0cVerifyStatus\x12\x0b\n\x07UNKNOWN\x10\x00\x12\n\n\x06\x41\x43\x43\x45PT\x10\x01\x12\n\n\x06REJECT\x10\x02\"\xfd\x02\n\x15ResponseFinalizeBlock\x12N\n\x06\x65vents\x18\x01 \x03(\x0b\x32\x1c.cometbft.abci.v1beta2.EventB\x18\xc8\xde\x1f\x00\xea\xde\x1f\x10\x65vents,omitemptyR\x06\x65vents\x12\x42\n\ntx_results\x18\x02 \x03(\x0b\x32#.cometbft.abci.v1beta3.ExecTxResultR\ttxResults\x12Y\n\x11validator_updates\x18\x03 \x03(\x0b\x32&.cometbft.abci.v1beta1.ValidatorUpdateB\x04\xc8\xde\x1f\x00R\x10validatorUpdates\x12Z\n\x17\x63onsensus_param_updates\x18\x04 \x01(\x0b\x32\".cometbft.types.v1.ConsensusParamsR\x15\x63onsensusParamUpdates\x12\x19\n\x08\x61pp_hash\x18\x05 \x01(\x0cR\x07\x61ppHash\"\x9f\x01\n\x08VoteInfo\x12\x44\n\tvalidator\x18\x01 \x01(\x0b\x32 .cometbft.abci.v1beta1.ValidatorB\x04\xc8\xde\x1f\x00R\tvalidator\x12G\n\rblock_id_flag\x18\x03 \x01(\x0e\x32#.cometbft.types.v1beta1.BlockIDFlagR\x0b\x62lockIdFlagJ\x04\x08\x02\x10\x03\"\xff\x01\n\x10\x45xtendedVoteInfo\x12\x44\n\tvalidator\x18\x01 \x01(\x0b\x32 .cometbft.abci.v1beta1.ValidatorB\x04\xc8\xde\x1f\x00R\tvalidator\x12%\n\x0evote_extension\x18\x03 \x01(\x0cR\rvoteExtension\x12/\n\x13\x65xtension_signature\x18\x04 \x01(\x0cR\x12\x65xtensionSignature\x12G\n\rblock_id_flag\x18\x05 \x01(\x0e\x32#.cometbft.types.v1beta1.BlockIDFlagR\x0b\x62lockIdFlagJ\x04\x08\x02\x10\x03\"_\n\nCommitInfo\x12\x14\n\x05round\x18\x01 \x01(\x05R\x05round\x12;\n\x05votes\x18\x02 \x03(\x0b\x32\x1f.cometbft.abci.v1beta3.VoteInfoB\x04\xc8\xde\x1f\x00R\x05votes\"o\n\x12\x45xtendedCommitInfo\x12\x14\n\x05round\x18\x01 \x01(\x05R\x05round\x12\x43\n\x05votes\x18\x02 \x03(\x0b\x32\'.cometbft.abci.v1beta3.ExtendedVoteInfoB\x04\xc8\xde\x1f\x00R\x05votes\"\x86\x02\n\x0c\x45xecTxResult\x12\x12\n\x04\x63ode\x18\x01 \x01(\rR\x04\x63ode\x12\x12\n\x04\x64\x61ta\x18\x02 \x01(\x0cR\x04\x64\x61ta\x12\x10\n\x03log\x18\x03 \x01(\tR\x03log\x12\x12\n\x04info\x18\x04 \x01(\tR\x04info\x12\x1e\n\ngas_wanted\x18\x05 \x01(\x03R\ngas_wanted\x12\x1a\n\x08gas_used\x18\x06 \x01(\x03R\x08gas_used\x12N\n\x06\x65vents\x18\x07 \x03(\x0b\x32\x1c.cometbft.abci.v1beta2.EventB\x18\xc8\xde\x1f\x00\xea\xde\x1f\x10\x65vents,omitemptyR\x06\x65vents\x12\x1c\n\tcodespace\x18\x08 \x01(\tR\tcodespace\"\x8b\x01\n\x08TxResult\x12\x16\n\x06height\x18\x01 \x01(\x03R\x06height\x12\x14\n\x05index\x18\x02 \x01(\rR\x05index\x12\x0e\n\x02tx\x18\x03 \x01(\x0cR\x02tx\x12\x41\n\x06result\x18\x04 \x01(\x0b\x32#.cometbft.abci.v1beta3.ExecTxResultB\x04\xc8\xde\x1f\x00R\x06result2\xdd\x0c\n\x04\x41\x42\x43I\x12O\n\x04\x45\x63ho\x12\".cometbft.abci.v1beta1.RequestEcho\x1a#.cometbft.abci.v1beta1.ResponseEcho\x12R\n\x05\x46lush\x12#.cometbft.abci.v1beta1.RequestFlush\x1a$.cometbft.abci.v1beta1.ResponseFlush\x12O\n\x04Info\x12\".cometbft.abci.v1beta2.RequestInfo\x1a#.cometbft.abci.v1beta1.ResponseInfo\x12X\n\x07\x43heckTx\x12%.cometbft.abci.v1beta1.RequestCheckTx\x1a&.cometbft.abci.v1beta3.ResponseCheckTx\x12R\n\x05Query\x12#.cometbft.abci.v1beta1.RequestQuery\x1a$.cometbft.abci.v1beta1.ResponseQuery\x12U\n\x06\x43ommit\x12$.cometbft.abci.v1beta1.RequestCommit\x1a%.cometbft.abci.v1beta3.ResponseCommit\x12^\n\tInitChain\x12\'.cometbft.abci.v1beta3.RequestInitChain\x1a(.cometbft.abci.v1beta3.ResponseInitChain\x12j\n\rListSnapshots\x12+.cometbft.abci.v1beta1.RequestListSnapshots\x1a,.cometbft.abci.v1beta1.ResponseListSnapshots\x12j\n\rOfferSnapshot\x12+.cometbft.abci.v1beta1.RequestOfferSnapshot\x1a,.cometbft.abci.v1beta1.ResponseOfferSnapshot\x12v\n\x11LoadSnapshotChunk\x12/.cometbft.abci.v1beta1.RequestLoadSnapshotChunk\x1a\x30.cometbft.abci.v1beta1.ResponseLoadSnapshotChunk\x12y\n\x12\x41pplySnapshotChunk\x12\x30.cometbft.abci.v1beta1.RequestApplySnapshotChunk\x1a\x31.cometbft.abci.v1beta1.ResponseApplySnapshotChunk\x12p\n\x0fPrepareProposal\x12-.cometbft.abci.v1beta3.RequestPrepareProposal\x1a..cometbft.abci.v1beta2.ResponsePrepareProposal\x12p\n\x0fProcessProposal\x12-.cometbft.abci.v1beta3.RequestProcessProposal\x1a..cometbft.abci.v1beta2.ResponseProcessProposal\x12\x61\n\nExtendVote\x12(.cometbft.abci.v1beta3.RequestExtendVote\x1a).cometbft.abci.v1beta3.ResponseExtendVote\x12|\n\x13VerifyVoteExtension\x12\x31.cometbft.abci.v1beta3.RequestVerifyVoteExtension\x1a\x32.cometbft.abci.v1beta3.ResponseVerifyVoteExtension\x12j\n\rFinalizeBlock\x12+.cometbft.abci.v1beta3.RequestFinalizeBlock\x1a,.cometbft.abci.v1beta3.ResponseFinalizeBlockB\xd5\x01\n\x19\x63om.cometbft.abci.v1beta3B\nTypesProtoP\x01Z6github.com/cometbft/cometbft/api/cometbft/abci/v1beta3\xa2\x02\x03\x43\x41X\xaa\x02\x15\x43ometbft.Abci.V1beta3\xca\x02\x15\x43ometbft\\Abci\\V1beta3\xe2\x02!Cometbft\\Abci\\V1beta3\\GPBMetadata\xea\x02\x17\x43ometbft::Abci::V1beta3b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cometbft.abci.v1beta3.types_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\031com.cometbft.abci.v1beta3B\nTypesProtoP\001Z6github.com/cometbft/cometbft/api/cometbft/abci/v1beta3\242\002\003CAX\252\002\025Cometbft.Abci.V1beta3\312\002\025Cometbft\\Abci\\V1beta3\342\002!Cometbft\\Abci\\V1beta3\\GPBMetadata\352\002\027Cometbft::Abci::V1beta3'
  _globals['_REQUESTINITCHAIN'].fields_by_name['time']._loaded_options = None
  _globals['_REQUESTINITCHAIN'].fields_by_name['time']._serialized_options = b'\310\336\037\000\220\337\037\001'
  _globals['_REQUESTINITCHAIN'].fields_by_name['validators']._loaded_options = None
  _globals['_REQUESTINITCHAIN'].fields_by_name['validators']._serialized_options = b'\310\336\037\000'
  _globals['_REQUESTPREPAREPROPOSAL'].fields_by_name['local_last_commit']._loaded_options = None
  _globals['_REQUESTPREPAREPROPOSAL'].fields_by_name['local_last_commit']._serialized_options = b'\310\336\037\000'
  _globals['_REQUESTPREPAREPROPOSAL'].fields_by_name['misbehavior']._loaded_options = None
  _globals['_REQUESTPREPAREPROPOSAL'].fields_by_name['misbehavior']._serialized_options = b'\310\336\037\000'
  _globals['_REQUESTPREPAREPROPOSAL'].fields_by_name['time']._loaded_options = None
  _globals['_REQUESTPREPAREPROPOSAL'].fields_by_name['time']._serialized_options = b'\310\336\037\000\220\337\037\001'
  _globals['_REQUESTPROCESSPROPOSAL'].fields_by_name['proposed_last_commit']._loaded_options = None
  _globals['_REQUESTPROCESSPROPOSAL'].fields_by_name['proposed_last_commit']._serialized_options = b'\310\336\037\000'
  _globals['_REQUESTPROCESSPROPOSAL'].fields_by_name['misbehavior']._loaded_options = None
  _globals['_REQUESTPROCESSPROPOSAL'].fields_by_name['misbehavior']._serialized_options = b'\310\336\037\000'
  _globals['_REQUESTPROCESSPROPOSAL'].fields_by_name['time']._loaded_options = None
  _globals['_REQUESTPROCESSPROPOSAL'].fields_by_name['time']._serialized_options = b'\310\336\037\000\220\337\037\001'
  _globals['_REQUESTEXTENDVOTE'].fields_by_name['time']._loaded_options = None
  _globals['_REQUESTEXTENDVOTE'].fields_by_name['time']._serialized_options = b'\310\336\037\000\220\337\037\001'
  _globals['_REQUESTEXTENDVOTE'].fields_by_name['proposed_last_commit']._loaded_options = None
  _globals['_REQUESTEXTENDVOTE'].fields_by_name['proposed_last_commit']._serialized_options = b'\310\336\037\000'
  _globals['_REQUESTEXTENDVOTE'].fields_by_name['misbehavior']._loaded_options = None
  _globals['_REQUESTEXTENDVOTE'].fields_by_name['misbehavior']._serialized_options = b'\310\336\037\000'
  _globals['_REQUESTFINALIZEBLOCK'].fields_by_name['decided_last_commit']._loaded_options = None
  _globals['_REQUESTFINALIZEBLOCK'].fields_by_name['decided_last_commit']._serialized_options = b'\310\336\037\000'
  _globals['_REQUESTFINALIZEBLOCK'].fields_by_name['misbehavior']._loaded_options = None
  _globals['_REQUESTFINALIZEBLOCK'].fields_by_name['misbehavior']._serialized_options = b'\310\336\037\000'
  _globals['_REQUESTFINALIZEBLOCK'].fields_by_name['time']._loaded_options = None
  _globals['_REQUESTFINALIZEBLOCK'].fields_by_name['time']._serialized_options = b'\310\336\037\000\220\337\037\001'
  _globals['_RESPONSEINITCHAIN'].fields_by_name['validators']._loaded_options = None
  _globals['_RESPONSEINITCHAIN'].fields_by_name['validators']._serialized_options = b'\310\336\037\000'
  _globals['_RESPONSECHECKTX'].fields_by_name['events']._loaded_options = None
  _globals['_RESPONSECHECKTX'].fields_by_name['events']._serialized_options = b'\310\336\037\000\352\336\037\020events,omitempty'
  _globals['_RESPONSEFINALIZEBLOCK'].fields_by_name['events']._loaded_options = None
  _globals['_RESPONSEFINALIZEBLOCK'].fields_by_name['events']._serialized_options = b'\310\336\037\000\352\336\037\020events,omitempty'
  _globals['_RESPONSEFINALIZEBLOCK'].fields_by_name['validator_updates']._loaded_options = None
  _globals['_RESPONSEFINALIZEBLOCK'].fields_by_name['validator_updates']._serialized_options = b'\310\336\037\000'
  _globals['_VOTEINFO'].fields_by_name['validator']._loaded_options = None
  _globals['_VOTEINFO'].fields_by_name['validator']._serialized_options = b'\310\336\037\000'
  _globals['_EXTENDEDVOTEINFO'].fields_by_name['validator']._loaded_options = None
  _globals['_EXTENDEDVOTEINFO'].fields_by_name['validator']._serialized_options = b'\310\336\037\000'
  _globals['_COMMITINFO'].fields_by_name['votes']._loaded_options = None
  _globals['_COMMITINFO'].fields_by_name['votes']._serialized_options = b'\310\336\037\000'
  _globals['_EXTENDEDCOMMITINFO'].fields_by_name['votes']._loaded_options = None
  _globals['_EXTENDEDCOMMITINFO'].fields_by_name['votes']._serialized_options = b'\310\336\037\000'
  _globals['_EXECTXRESULT'].fields_by_name['events']._loaded_options = None
  _globals['_EXECTXRESULT'].fields_by_name['events']._serialized_options = b'\310\336\037\000\352\336\037\020events,omitempty'
  _globals['_TXRESULT'].fields_by_name['result']._loaded_options = None
  _globals['_TXRESULT'].fields_by_name['result']._serialized_options = b'\310\336\037\000'
  _globals['_REQUEST']._serialized_start=258
  _globals['_REQUEST']._serialized_end=1569
  _globals['_REQUESTINITCHAIN']._serialized_start=1572
  _globals['_REQUESTINITCHAIN']._serialized_end=1911
  _globals['_REQUESTPREPAREPROPOSAL']._serialized_start=1914
  _globals['_REQUESTPREPAREPROPOSAL']._serialized_end=2334
  _globals['_REQUESTPROCESSPROPOSAL']._serialized_start=2337
  _globals['_REQUESTPROCESSPROPOSAL']._serialized_end=2741
  _globals['_REQUESTEXTENDVOTE']._serialized_start=2744
  _globals['_REQUESTEXTENDVOTE']._serialized_end=3143
  _globals['_REQUESTVERIFYVOTEEXTENSION']._serialized_start=3146
  _globals['_REQUESTVERIFYVOTEEXTENSION']._serialized_end=3302
  _globals['_REQUESTFINALIZEBLOCK']._serialized_start=3305
  _globals['_REQUESTFINALIZEBLOCK']._serialized_end=3705
  _globals['_RESPONSE']._serialized_start=3708
  _globals['_RESPONSE']._serialized_end=5110
  _globals['_RESPONSEINITCHAIN']._serialized_start=5113
  _globals['_RESPONSEINITCHAIN']._serialized_end=5316
  _globals['_RESPONSECHECKTX']._serialized_start=5319
  _globals['_RESPONSECHECKTX']._serialized_end=5623
  _globals['_RESPONSECOMMIT']._serialized_start=5625
  _globals['_RESPONSECOMMIT']._serialized_end=5690
  _globals['_RESPONSEEXTENDVOTE']._serialized_start=5692
  _globals['_RESPONSEEXTENDVOTE']._serialized_end=5751
  _globals['_RESPONSEVERIFYVOTEEXTENSION']._serialized_start=5754
  _globals['_RESPONSEVERIFYVOTEEXTENSION']._serialized_end=5925
  _globals['_RESPONSEVERIFYVOTEEXTENSION_VERIFYSTATUS']._serialized_start=5874
  _globals['_RESPONSEVERIFYVOTEEXTENSION_VERIFYSTATUS']._serialized_end=5925
  _globals['_RESPONSEFINALIZEBLOCK']._serialized_start=5928
  _globals['_RESPONSEFINALIZEBLOCK']._serialized_end=6309
  _globals['_VOTEINFO']._serialized_start=6312
  _globals['_VOTEINFO']._serialized_end=6471
  _globals['_EXTENDEDVOTEINFO']._serialized_start=6474
  _globals['_EXTENDEDVOTEINFO']._serialized_end=6729
  _globals['_COMMITINFO']._serialized_start=6731
  _globals['_COMMITINFO']._serialized_end=6826
  _globals['_EXTENDEDCOMMITINFO']._serialized_start=6828
  _globals['_EXTENDEDCOMMITINFO']._serialized_end=6939
  _globals['_EXECTXRESULT']._serialized_start=6942
  _globals['_EXECTXRESULT']._serialized_end=7204
  _globals['_TXRESULT']._serialized_start=7207
  _globals['_TXRESULT']._serialized_end=7346
  _globals['_ABCI']._serialized_start=7349
  _globals['_ABCI']._serialized_end=8978
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/api/expr/v1beta1/decl.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.google.api.expr.v1beta1 import expr_pb2 as google_dot_api_dot_expr_dot_v1beta1_dot_expr__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"google/api/expr/v1beta1/decl.proto\x12\x17google.api.expr.v1beta1\x1a\"google/api/expr/v1beta1/expr.proto\"\xc5\x01\n\x04\x44\x65\x63l\x12\x0e\n\x02id\x18\x01 \x01(\x05R\x02id\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12\x10\n\x03\x64oc\x18\x03 \x01(\tR\x03\x64oc\x12:\n\x05ident\x18\x04 \x01(\x0b\x32\".google.api.expr.v1beta1.IdentDeclH\x00R\x05ident\x12\x43\n\x08\x66unction\x18\x05 \x01(\x0b\x32%.google.api.expr.v1beta1.FunctionDeclH\x00R\x08\x66unctionB\x06\n\x04kind\"r\n\x08\x44\x65\x63lType\x12\x0e\n\x02id\x18\x01 \x01(\x05R\x02id\x12\x12\n\x04type\x18\x02 \x01(\tR\x04type\x12\x42\n\x0btype_params\x18\x04 \x03(\x0b\x32!.google.api.expr.v1beta1.DeclTypeR\ntypeParams\"w\n\tIdentDecl\x12\x35\n\x04type\x18\x03 \x01(\x0b\x32!.google.api.expr.v1beta1.DeclTypeR\x04type\x12\x33\n\x05value\x18\x04 \x01(\x0b\x32\x1d.google.api.expr.v1beta1.ExprR\x05value\"\xb7\x01\n\x0c\x46unctionDecl\x12\x36\n\x04\x61rgs\x18\x01 \x03(\x0b\x32\".google.api.expr.v1beta1.IdentDeclR\x04\x61rgs\x12\x42\n\x0breturn_type\x18\x02 \x01(\x0b\x32!.google.api.expr.v1beta1.DeclTypeR\nreturnType\x12+\n\x11receiver_function\x18\x03 \x01(\x08R\x10receiverFunctionB\xe7\x01\n\x1b\x63om.google.api.expr.v1beta1B\tDeclProtoP\x01Z;google.golang.org/genproto/googleapis/api/expr/v1beta1;expr\xf8\x01\x01\xa2\x02\x03GAE\xaa\x02\x17Google.Api.Expr.V1beta1\xca\x02\x17Google\\Api\\Expr\\V1beta1\xe2\x02#Google\\Api\\Expr\\V1beta1\\GPBMetadata\xea\x02\x1aGoogle::Api::Expr::V1beta1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'google.api.expr.v1beta1.decl_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\033com.google.api.expr.v1beta1B\tDeclProtoP\001Z;google.golang.org/genproto/googleapis/api/expr/v1beta1;expr\370\001\001\242\002\003GAE\252\002\027Google.Api.Expr.V1beta1\312\002\027Google\\Api\\Expr\\V1beta1\342\002#Google\\Api\\Expr\\V1beta1\\GPBMetadata\352\002\032Google::Api::Expr::V1beta1'
  _globals['_DECL']._serialized_start=100
  _globals['_DECL']._serialized_end=297
  _globals['_DECLTYPE']._serialized_start=299
  _globals['_DECLTYPE']._serialized_end=413
  _globals['_IDENTDECL']._serialized_start=415
  _globals['_IDENTDECL']._serialized_end=534
  _globals['_FUNCTIONDECL']._serialized_start=537
  _globals['_FUNCTIONDECL']._serialized_end=720
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cometbft/p2p/v1/pex.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.cometbft.p2p.v1 import types_pb2 as cometbft_dot_p2p_dot_v1_dot_types__pb2
from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19\x63ometbft/p2p/v1/pex.proto\x12\x0f\x63ometbft.p2p.v1\x1a\x1b\x63ometbft/p2p/v1/types.proto\x1a\x14gogoproto/gogo.proto\"\x0c\n\nPexRequest\"C\n\x08PexAddrs\x12\x37\n\x05\x61\x64\x64rs\x18\x01 \x03(\x0b\x32\x1b.cometbft.p2p.v1.NetAddressB\x04\xc8\xde\x1f\x00R\x05\x61\x64\x64rs\"\x8a\x01\n\x07Message\x12>\n\x0bpex_request\x18\x01 \x01(\x0b\x32\x1b.cometbft.p2p.v1.PexRequestH\x00R\npexRequest\x12\x38\n\tpex_addrs\x18\x02 \x01(\x0b\x32\x19.cometbft.p2p.v1.PexAddrsH\x00R\x08pexAddrsB\x05\n\x03sumB\xaf\x01\n\x13\x63om.cometbft.p2p.v1B\x08PexProtoP\x01Z0github.com/cometbft/cometbft/api/cometbft/p2p/v1\xa2\x02\x03\x43PX\xaa\x02\x0f\x43ometbft.P2p.V1\xca\x02\x0f\x43ometbft\\P2p\\V1\xe2\x02\x1b\x43ometbft\\P2p\\V1\\GPBMetadata\xea\x02\x11\x43ometbft::P2p::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cometbft.p2p.v1.pex_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\023com.cometbft.p2p.v1B\010PexProtoP\001Z0github.com/cometbft/cometbft/api/cometbft/p2p/v1\242\002\003CPX\252\002\017Cometbft.P2p.V1\312\002\017Cometbft\\P2p\\V1\342\002\033Cometbft\\P2p\\V1\\GPBMetadata\352\002\021Cometbft::P2p::V1'
  _globals['_PEXADDRS'].fields_by_name['addrs']._loaded_options = None
  _globals['_PEXADDRS'].fields_by_name['addrs']._serialized_options = b'\310\336\037\000'
  _globals['_PEXREQUEST']._serialized_start=97
  _globals['_PEXREQUEST']._serialized_end=109
  _globals['_PEXADDRS']._serialized_start=111
  _globals['_PEXADDRS']._serialized_end=178
  _globals['_MESSAGE']._serialized_start=181
  _globals['_MESSAGE']._serialized_end=319
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/base/query/v1beta1/pagination.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*cosmos/base/query/v1beta1/pagination.proto\x12\x19\x63osmos.base.query.v1beta1\"\x88\x01\n\x0bPageRequest\x12\x10\n\x03key\x18\x01 \x01(\x0cR\x03key\x12\x16\n\x06offset\x18\x02 \x01(\x04R\x06offset\x12\x14\n\x05limit\x18\x03 \x01(\x04R\x05limit\x12\x1f\n\x0b\x63ount_total\x18\x04 \x01(\x08R\ncountTotal\x12\x18\n\x07reverse\x18\x05 \x01(\x08R\x07reverse\"?\n\x0cPageResponse\x12\x19\n\x08next_key\x18\x01 \x01(\x0cR\x07nextKey\x12\x14\n\x05total\x18\x02 \x01(\x04R\x05totalB\xe1\x01\n\x1d\x63om.cosmos.base.query.v1beta1B\x0fPaginationProtoP\x01Z(github.com/cosmos/cosmos-sdk/types/query\xa2\x02\x03\x43\x42Q\xaa\x02\x19\x43osmos.Base.Query.V1beta1\xca\x02\x19\x43osmos\\Base\\Query\\V1beta1\xe2\x02%Cosmos\\Base\\Query\\V1beta1\\GPBMetadata\xea\x02\x1c\x43osmos::Base::Query::V1beta1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.base.query.v1beta1.pagination_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\035com.cosmos.base.query.v1beta1B\017PaginationProtoP\001Z(github.com/cosmos/cosmos-sdk/types/query\242\002\003CBQ\252\002\031Cosmos.Base.Query.V1beta1\312\002\031Cosmos\\Base\\Query\\V1beta1\342\002%Cosmos\\Base\\Query\\V1beta1\\GPBMetadata\352\002\034Cosmos::Base::Query::V1beta1'
  _globals['_PAGEREQUEST']._serialized_start=74
  _globals['_PAGEREQUEST']._serialized_end=210
  _globals['_PAGERESPONSE']._serialized_start=212
  _globals['_PAGERESPONSE']._serialized_end=275
# @@protoc_insertion_point(module_scope)
